@@ -33,6 +33,7 @@
 #include <ql/indexes/iborindex.hpp>
 #include <ql/patterns/singleton.hpp>
 #include <ql/time/schedule.hpp>
+#include <ql/optional.hpp>
 
 namespace QuantLib {
 
@@ -99,18 +100,6 @@ namespace QuantLib {
       public:
         // IborCoupon::Settings forward declaration
         class Settings;
-        /*! \deprecated Use IborCouponSettings::Settings::instance().createAtParCoupons() instead
-                        Deprecated in version 1.24.
-        */
-        QL_DEPRECATED static void createAtParCoupons();
-        /*! \deprecated Use IborCouponSettings::Settings::instance().createIndexedCoupons() instead
-                        Deprecated in version 1.24.
-        */
-        QL_DEPRECATED static void createIndexedCoupons();
-        /*! \deprecated Use IborCouponSettings::Settings::instance().usingAtParCoupons() instead
-                        Deprecated in version 1.24.
-        */
-        QL_DEPRECATED static bool usingAtParCoupons();
     };
 
 
@@ -166,7 +155,7 @@ namespace QuantLib {
                                     const Calendar&,
                                     BusinessDayConvention,
                                     bool endOfMonth = false);
-        IborLeg& withIndexedCoupons(boost::optional<bool> b = true);
+        IborLeg& withIndexedCoupons(ext::optional<bool> b = true);
         IborLeg& withAtParCoupons(bool b = true);
         operator Leg() const;
 
@@ -187,7 +176,7 @@ namespace QuantLib {
         Calendar exCouponCalendar_;
         BusinessDayConvention exCouponAdjustment_ = Unadjusted;
         bool exCouponEndOfMonth_ = false;
-        boost::optional<bool> useIndexedCoupons_;
+        ext::optional<bool> useIndexedCoupons_;
     };
 
 }
