@@ -24,17 +24,18 @@
 */
 
 #include <ql/functional.hpp>
+#include <ql/instruments/payoffs.hpp>
+#include <ql/math/integrals/discreteintegrals.hpp>
+#include <ql/math/integrals/exponentialintegrals.hpp>
+#include <ql/math/integrals/gausslobattointegral.hpp>
+#include <ql/math/integrals/kronrodintegral.hpp>
+#include <ql/math/integrals/simpsonintegral.hpp>
+#include <ql/math/integrals/trapezoidintegral.hpp>
 #include <ql/math/solvers1d/brent.hpp>
 #include <ql/math/functional.hpp>
-#include <ql/math/integrals/simpsonintegral.hpp>
-#include <ql/math/integrals/kronrodintegral.hpp>
-#include <ql/math/integrals/trapezoidintegral.hpp>
-#include <ql/math/integrals/discreteintegrals.hpp>
-#include <ql/math/integrals/gausslobattointegral.hpp>
-
-#include <ql/instruments/payoffs.hpp>
 #include <ql/pricingengines/blackcalculator.hpp>
 #include <ql/pricingengines/vanilla/analytichestonengine.hpp>
+#include <utility>
 
 #if defined(QL_PATCH_MSVC)
 #pragma warning(disable: 4180)
@@ -49,8 +50,7 @@ namespace QuantLib {
             const Real c_inf_;
             const ext::function<Real(Real)> f_;
           public:
-            integrand1(Real c_inf, const ext::function<Real(Real)>& f)
-            : c_inf_(c_inf), f_(f) {}
+            integrand1(Real c_inf, ext::function<Real(Real)> f) : c_inf_(c_inf), f_(std::move(f)) {}
             Real operator()(Real x) const {
                 if ((1.0-x)*c_inf_ > QL_EPSILON)
                     return f_(-std::log(0.5-0.5*x)/c_inf_)/((1.0-x)*c_inf_);
@@ -64,8 +64,7 @@ namespace QuantLib {
             const Real c_inf_;
             const ext::function<Real(Real)> f_;
           public:
-            integrand2(Real c_inf, const ext::function<Real(Real)>& f)
-            : c_inf_(c_inf), f_(f) {}
+            integrand2(Real c_inf, ext::function<Real(Real)> f) : c_inf_(c_inf), f_(std::move(f)) {}
             Real operator()(Real x) const {
                 if (x*c_inf_ > QL_EPSILON) {
                     return f_(-std::log(x)/c_inf_)/(x*c_inf_);
@@ -87,9 +86,7 @@ namespace QuantLib {
 
         class u_Max {
           public:
-            u_Max(Real c_inf, Real epsilon)
-            : c_inf_(c_inf), logEpsilon_(std::log(epsilon)),
-              evaluations_(0) {}
+            u_Max(Real c_inf, Real epsilon) : c_inf_(c_inf), logEpsilon_(std::log(epsilon)) {}
 
             Real operator()(Real u) const {
                 ++evaluations_;
@@ -100,15 +97,13 @@ namespace QuantLib {
 
           private:
             const Real c_inf_, logEpsilon_;
-            mutable Size evaluations_;
+            mutable Size evaluations_ = 0;
         };
 
 
         class uHat_Max {
           public:
-            uHat_Max(Real v0T2, Real epsilon)
-            : v0T2_(v0T2), logEpsilon_(std::log(epsilon)),
-              evaluations_(0) {}
+            uHat_Max(Real v0T2, Real epsilon) : v0T2_(v0T2), logEpsilon_(std::log(epsilon)) {}
 
             Real operator()(Real u) const {
                 ++evaluations_;
@@ -119,7 +114,7 @@ namespace QuantLib {
 
           private:
             const Real v0T2_, logEpsilon_;
-            mutable Size evaluations_;
+            mutable Size evaluations_ = 0;
         };
     }
 
@@ -197,7 +192,7 @@ namespace QuantLib {
         dd_(x_-std::log(ratio)),
         sigma2_(sigma_*sigma_),
         rsigma_(model->rho()*sigma_),
-        t0_(kappa_ - ((j_== 1)? model->rho()*sigma_ : 0)),
+        t0_(kappa_ - ((j_== 1)? model->rho()*sigma_ : Real(0))),
         b_(0), g_km1_(0),
         engine_(engine)
     {
@@ -224,39 +219,28 @@ namespace QuantLib {
         dd_(x_-std::log(ratio)),
         sigma2_(sigma_*sigma_),
         rsigma_(rho*sigma_),
-        t0_(kappa - ((j== 1)? rho*sigma : 0)),
+        t0_(kappa - ((j== 1)? rho*sigma : Real(0))),
         b_(0),
         g_km1_(0),
         engine_(engine)
     {
     }
 
-    AnalyticHestonEngine::Fj_Helper::Fj_Helper(Real kappa, Real theta,
-        Real sigma, Real v0, Real s0, Real rho,
-        ComplexLogFormula cpxLog,
-        Time term,
-        Real strike,
-        Real ratio,
-        Size j)
-        :
-        j_(j),
-        kappa_(kappa),
-        theta_(theta),
-        sigma_(sigma),
-        v0_(v0),
-        cpxLog_(cpxLog),
-        term_(term),
-        x_(std::log(s0)),
-        sx_(std::log(strike)),
-        dd_(x_-std::log(ratio)),
-        sigma2_(sigma_*sigma_),
-        rsigma_(rho*sigma_),
-        t0_(kappa - ((j== 1)? rho*sigma : 0)),
-        b_(0),
-        g_km1_(0),
-        engine_(0)
-    {
-    }
+    AnalyticHestonEngine::Fj_Helper::Fj_Helper(Real kappa,
+                                               Real theta,
+                                               Real sigma,
+                                               Real v0,
+                                               Real s0,
+                                               Real rho,
+                                               ComplexLogFormula cpxLog,
+                                               Time term,
+                                               Real strike,
+                                               Real ratio,
+                                               Size j)
+    : j_(j), kappa_(kappa), theta_(theta), sigma_(sigma), v0_(v0), cpxLog_(cpxLog), term_(term),
+      x_(std::log(s0)), sx_(std::log(strike)), dd_(x_ - std::log(ratio)), sigma2_(sigma_ * sigma_),
+      rsigma_(rho * sigma_), t0_(kappa - ((j == 1) ? rho * sigma : Real(0))), b_(0), g_km1_(0),
+      engine_(nullptr) {}
 
 
     Real AnalyticHestonEngine::Fj_Helper::operator()(Real phi) const
@@ -269,7 +253,7 @@ namespace QuantLib {
                       *std::complex<Real>(-phi, (j_== 1)? 1 : -1));
         const std::complex<Real> ex = std::exp(-d*term_);
         const std::complex<Real> addOnTerm =
-            engine_ != 0 ? engine_->addOnTerm(phi, term_, j_) : Real(0.0);
+            engine_ != nullptr ? engine_->addOnTerm(phi, term_, j_) : Real(0.0);
 
         if (cpxLog_ == Gatheral) {
             if (phi != 0.0) {
@@ -377,43 +361,95 @@ namespace QuantLib {
     }
 
 
-    class AnalyticHestonEngine::AP_Helper {
-      public:
-        AP_Helper(Time term, Real s0, Real strike, Real ratio,
-                  Volatility sigmaBS,
-                  const AnalyticHestonEngine* const enginePtr)
-        : term_(term),
-          sigmaBS_(sigmaBS),
-          x_(std::log(s0)),
-          sx_(std::log(strike)),
-          dd_(x_-std::log(ratio)),
-          enginePtr_(enginePtr) {
-            QL_REQUIRE(enginePtr != 0, "pricing engine required");
+    AnalyticHestonEngine::AP_Helper::AP_Helper(
+        Time term, Real fwd, Real strike, ComplexLogFormula cpxLog,
+        const AnalyticHestonEngine* const enginePtr)
+    : term_(term),
+      fwd_(fwd),
+      strike_(strike),
+      freq_(std::log(fwd/strike)),
+      cpxLog_(cpxLog),
+      enginePtr_(enginePtr) {
+        QL_REQUIRE(enginePtr != nullptr, "pricing engine required");
+
+        const Real v0    = enginePtr->model_->v0();
+        const Real kappa = enginePtr->model_->kappa();
+        const Real theta = enginePtr->model_->theta();
+        const Real sigma = enginePtr->model_->sigma();
+        const Real rho   = enginePtr->model_->rho();
+
+        switch(cpxLog_) {
+          case AndersenPiterbarg:
+              vAvg_ = (1-std::exp(-kappa*term))*(v0 - theta)
+                        /(kappa*term) + theta;
+            break;
+          case AndersenPiterbargOptCV:
+              vAvg_ = -8.0*std::log(enginePtr->chF(
+                         std::complex<Real>(0, -0.5), term).real())/term;
+            break;
+          case AsymptoticChF:
+            phi_ = -(v0+term*kappa*theta)/sigma
+                * std::complex<Real>(std::sqrt(1-rho*rho), rho);
+
+            psi_ = std::complex<Real>(
+                (kappa- 0.5*rho*sigma)*(v0 + term*kappa*theta)
+                + kappa*theta*std::log(4*(1-rho*rho)),
+                - ((0.5*rho*rho*sigma - kappa*rho)/std::sqrt(1-rho*rho)
+                        *(v0 + kappa*theta*term)
+                  - 2*kappa*theta*std::atan(rho/std::sqrt(1-rho*rho))))
+                          /(sigma*sigma);
+            break;
+          default:
+            QL_FAIL("unknown control variate");
+        }
+    }
+
+    Real AnalyticHestonEngine::AP_Helper::operator()(Real u) const {
+        QL_REQUIRE(   enginePtr_->addOnTerm(u, term_, 1)
+                        == std::complex<Real>(0.0)
+                   && enginePtr_->addOnTerm(u, term_, 2)
+                        == std::complex<Real>(0.0),
+                   "only Heston model is supported");
+
+        const std::complex<Real> z(u, -0.5);
+
+        std::complex<Real> phiBS;
+
+        switch (cpxLog_) {
+          case AndersenPiterbarg:
+          case AndersenPiterbargOptCV:
+            phiBS = std::exp(
+                -0.5*vAvg_*term_*(z*z + std::complex<Real>(-z.imag(), z.real())));
+            break;
+          case AsymptoticChF:
+            phiBS = std::exp(u*phi_ + psi_);
+            break;
+          default:
+            QL_FAIL("unknown control variate");
         }
 
-        Real operator()(Real u) const {
-            QL_REQUIRE(   enginePtr_->addOnTerm(u, term_, 1)
-                            == std::complex<Real>(0.0)
-                       && enginePtr_->addOnTerm(u, term_, 2)
-                            == std::complex<Real>(0.0),
-                       "only Heston model is supported");
+        return (std::exp(std::complex<Real>(0.0, u*freq_))
+            * (phiBS - enginePtr_->chF(z, term_)) / (u*u + 0.25)).real();
+    }
 
-            const std::complex<Real> z(u, -0.5);
-
-            const std::complex<Real> phiBS
-                = std::exp(-0.5*sigmaBS_*sigmaBS_*term_
-                           *(z*z + std::complex<Real>(-z.imag(), z.real())));
-
-            return (std::exp(std::complex<Real>(0.0, u*(dd_-sx_)))
-                * (phiBS - enginePtr_->chF(z, term_)) / (u*u + 0.25)).real();
+    Real AnalyticHestonEngine::AP_Helper::controlVariateValue() const {
+        if (cpxLog_ == AndersenPiterbarg || cpxLog_ == AndersenPiterbargOptCV) {
+              return BlackCalculator(
+                  Option::Call, strike_, fwd_, std::sqrt(vAvg_*term_))
+                      .value();
         }
+        else if (cpxLog_ == AsymptoticChF) {
+            const std::complex<Real> phiFreq(phi_.real(), phi_.imag() + freq_);
 
-      private:
-        const Time term_;
-        const Volatility sigmaBS_;
-        const Real x_, sx_, dd_;
-        const AnalyticHestonEngine* const enginePtr_;
-    };
+            using namespace ExponentialIntegral;
+            return fwd_ - std::sqrt(strike_*fwd_)/M_PI*
+                (std::exp(psi_)*(
+                      -2.0*Ci(-0.5*phiFreq)*std::sin(0.5*phiFreq)
+                       +std::cos(0.5*phiFreq)*(M_PI+2.0*Si(0.5*phiFreq)))).real();
+        }
+        else
+            QL_FAIL("unknown control variate");
+    }
 
     std::complex<Real> AnalyticHestonEngine::chF(
         const std::complex<Real>& z, Time t) const {
@@ -456,14 +492,14 @@ namespace QuantLib {
                     /(2.*kappa*kappa)*sigma
                    + (std::exp(-2*kt - ((theta - v0 + ekt
                 *((-1 + kt)*theta + v0))*z*zpi)/(2.*ekt*kappa))*z*z*zpi
-                *(-2*rho2*square<Real>()(2*theta + kt*theta - v0 -
+                *(-2*rho2*squared(2*theta + kt*theta - v0 -
                     kt*v0 + ekt*((-2 + kt)*theta + v0))
                   *z*z*zpi + 2*kappa*v0*(-zpi
                     + e2kt*(zpi + 4*rho2*z) - 2*ekt*(2*rho2*z
                     + kt*(zpi + rho2*(2 + kt)*z))) + kappa*theta*(zpi + e2kt
                 *(-5.0*zpi - 24*rho2*z+ 2*kt*(zpi + 4*rho2*z)) +
                 4*ekt*(zpi + 6*rho2*z + kt*(zpi + rho2*(4 + kt)*z)))))
-                /(16.*square<Real>()(square<Real>()(kappa)))*sigma2;
+                /(16.*squared(squared(kappa)))*sigma2;
         }
     }
 
@@ -516,6 +552,19 @@ namespace QuantLib {
                    "with adaptive integration methods");
     }
 
+    AnalyticHestonEngine::ComplexLogFormula
+        AnalyticHestonEngine::optimalControlVariate(
+        Time t, Real v0, Real kappa, Real theta, Real sigma, Real rho) {
+
+        if (t > 0.1 && (v0+t*kappa*theta)/sigma*std::sqrt(1-rho*rho) < 0.055) {
+            return AsymptoticChF;
+        }
+        else {
+            return AndersenPiterbargOptCV;
+        }
+    }
+
+
     Size AnalyticHestonEngine::numberOfEvaluations() const {
         return evaluations_;
     }
@@ -569,7 +618,9 @@ namespace QuantLib {
           }
           break;
           case AndersenPiterbarg:
-          case AndersenPiterbargOptCV: {
+          case AndersenPiterbargOptCV:
+          case AsymptoticChF:
+          case OptimalCV: {
             const Real c_inf =
                 std::sqrt(1.0-rho*rho)*(v0 + kappa*theta*term)/sigma;
 
@@ -578,34 +629,30 @@ namespace QuantLib {
             const Real epsilon = enginePtr->andersenPiterbargEpsilon_
                 *M_PI/(std::sqrt(strikePrice*fwdPrice)*riskFreeDiscount);
 
-            const ext::function<Real()> uM = ext::bind(
-                Integration::andersenPiterbargIntegrationLimit,
-                    c_inf, epsilon, v0, term);
+            const ext::function<Real()> uM = [&](){
+                return Integration::andersenPiterbargIntegrationLimit(c_inf, epsilon, v0, term);
+            };
 
-            const Real vAvg = (cpxLog == AndersenPiterbarg)
-                ? (1-std::exp(-kappa*term))*(v0-theta)/(kappa*term) + theta
-                : -8.0*std::log(enginePtr->chF(
-                        std::complex<Real>(0, -0.5), term).real())/term;
+            AP_Helper cvHelper(term, fwdPrice, strikePrice,
+                (cpxLog == OptimalCV)
+                    ? optimalControlVariate(term, v0, kappa, theta, sigma, rho)
+                    : cpxLog,
+                enginePtr
+            );
 
-            const Real bsPrice
-                = BlackCalculator(Option::Call, strikePrice,
-                                  fwdPrice, std::sqrt(vAvg*term),
-                                  riskFreeDiscount).value();
+            const Real cvValue = cvHelper.controlVariateValue();
 
-            const Real h_cv = integration.calculate(c_inf,
-                    AP_Helper(term, spotPrice, strikePrice,
-                              ratio, std::sqrt(vAvg), enginePtr), uM)
-                * std::sqrt(strikePrice * fwdPrice)*riskFreeDiscount/M_PI;
+            const Real h_cv = integration.calculate(c_inf, cvHelper, uM)
+                * std::sqrt(strikePrice * fwdPrice)/M_PI;
             evaluations += integration.numberOfEvaluations();
 
             switch (type.optionType())
             {
               case Option::Call:
-                value = bsPrice + h_cv;
+                value = (cvValue + h_cv)*riskFreeDiscount;
                 break;
               case Option::Put:
-                value = bsPrice + h_cv
-                    - riskFreeDiscount*(fwdPrice - strikePrice);
+                value = (cvValue + h_cv - (fwdPrice - strikePrice))*riskFreeDiscount;
                 break;
               default:
                 QL_FAIL("unknown option type");
@@ -661,17 +708,13 @@ namespace QuantLib {
     }
 
 
-    AnalyticHestonEngine::Integration::Integration(
-            Algorithm intAlgo,
-            const ext::shared_ptr<Integrator>& integrator)
-    : intAlgo_(intAlgo),
-      integrator_(integrator) { }
+    AnalyticHestonEngine::Integration::Integration(Algorithm intAlgo,
+                                                   ext::shared_ptr<Integrator> integrator)
+    : intAlgo_(intAlgo), integrator_(std::move(integrator)) {}
 
     AnalyticHestonEngine::Integration::Integration(
-            Algorithm intAlgo,
-            const ext::shared_ptr<GaussianQuadrature>& gaussianQuadrature)
-    : intAlgo_(intAlgo),
-      gaussianQuadrature_(gaussianQuadrature) { }
+        Algorithm intAlgo, ext::shared_ptr<GaussianQuadrature> gaussianQuadrature)
+    : intAlgo_(intAlgo), gaussianQuadrature_(std::move(gaussianQuadrature)) {}
 
     AnalyticHestonEngine::Integration
     AnalyticHestonEngine::Integration::gaussLobatto(Real relTolerance,
@@ -756,12 +799,11 @@ namespace QuantLib {
     }
 
     Size AnalyticHestonEngine::Integration::numberOfEvaluations() const {
-        if (integrator_ != 0) {
+        if (integrator_ != nullptr) {
             return integrator_->numberOfEvaluations();
-        } else if (gaussianQuadrature_ != 0) {
+        } else if (gaussianQuadrature_ != nullptr) {
             return gaussianQuadrature_->order();
-        }
-        else {
+        } else {
             QL_FAIL("neither Integrator nor GaussianQuadrature given");
         }
     }
@@ -793,14 +835,14 @@ namespace QuantLib {
           case Trapezoid:
           case GaussLobatto:
           case GaussKronrod:
-              if (maxBound != 0 && maxBound() != Null<Real>())
+              if (maxBound && maxBound() != Null<Real>())
                   retVal = (*integrator_)(f, 0.0, maxBound());
               else
                   retVal = (*integrator_)(integrand2(c_inf, f), 0.0, 1.0);
               break;
           case DiscreteTrapezoid:
           case DiscreteSimpson:
-              if (maxBound != 0 && maxBound() != Null<Real>())
+              if (maxBound && maxBound() != Null<Real>())
                   retVal = (*integrator_)(f, 0.0, maxBound());
               else
                   retVal = (*integrator_)(integrand3(c_inf, f), 0.0, 1.0);
@@ -818,9 +860,7 @@ namespace QuantLib {
         Real maxBound) const {
 
         return AnalyticHestonEngine::Integration::calculate(
-            c_inf, f,
-            ext::bind(&constant<Real, Real>::operator(),
-                constant<Real, Real>(maxBound), 1.0));
+            c_inf, f, [=](){ return maxBound; });
     }
 
     Real AnalyticHestonEngine::Integration::andersenPiterbargIntegrationLimit(
