@@ -91,9 +91,19 @@ namespace QuantLib {
       public:
         class Integration;
         enum ComplexLogFormula {
-            Gatheral, BranchCorrection, AndersenPiterbarg,
-            // same as above but with a slightly better control variate
-            AndersenPiterbargOptCV
+            // Gatheral form of characteristic function w/o control variate
+            Gatheral,
+            // old branch correction form of the characteristic function w/o control variate
+            BranchCorrection,
+            // Gatheral form with Andersen-Piterbarg control variate
+            AndersenPiterbarg,
+            // same as AndersenPiterbarg, but a slightly better control variate
+            AndersenPiterbargOptCV,
+            // Gatheral form with asymptotic expansion of the characteristic function as control variate
+            // https://hpcquantlib.wordpress.com/2020/08/30/a-novel-control-variate-for-the-heston-model
+            AsymptoticChF,
+            // auto selection of best control variate algorithm from above
+            OptimalCV
         };
 
         // Simple to use constructor: Using adaptive
@@ -119,7 +129,7 @@ namespace QuantLib {
         std::complex<Real> chF(const std::complex<Real>& z, Time t) const;
         std::complex<Real> lnChF(const std::complex<Real>& z, Time t) const;
 
-        void calculate() const;
+        void calculate() const override;
         Size numberOfEvaluations() const;
 
         static void doCalculation(Real riskFreeDiscount,
@@ -127,14 +137,41 @@ namespace QuantLib {
                                   Real spotPrice,
                                   Real strikePrice,
                                   Real term,
-                                  Real kappa, Real theta, Real sigma, Real v0, Real rho,
+                                  Real kappa,
+                                  Real theta,
+                                  Real sigma,
+                                  Real v0,
+                                  Real rho,
                                   const TypePayoff& type,
                                   const Integration& integration,
-                                  const ComplexLogFormula cpxLog,
-                                  const AnalyticHestonEngine* const enginePtr,
+                                  ComplexLogFormula cpxLog,
+                                  const AnalyticHestonEngine* enginePtr,
                                   Real& value,
                                   Size& evaluations);
 
+        static ComplexLogFormula optimalControlVariate(
+             Time t, Real v0, Real kappa, Real theta, Real sigma, Real rho);
+
+        class AP_Helper {
+          public:
+            AP_Helper(Time term,
+                      Real fwd,
+                      Real strike,
+                      ComplexLogFormula cpxLog,
+                      const AnalyticHestonEngine* enginePtr);
+
+            Real operator()(Real u) const;
+            Real controlVariateValue() const;
+
+          private:
+            const Time term_;
+            const Real fwd_, strike_, freq_;
+            const ComplexLogFormula cpxLog_;
+            const AnalyticHestonEngine* const enginePtr_;
+            Real vAvg_;
+            std::complex<Real> phi_, psi_;
+        };
+
       protected:
         // call back for extended stochastic volatility
         // plus jump diffusion engines like bates model
@@ -144,7 +181,6 @@ namespace QuantLib {
 
       private:
         class Fj_Helper;
-        class AP_Helper;
 
         mutable Size evaluations_;
         const ComplexLogFormula cpxLog_;
@@ -183,7 +219,11 @@ namespace QuantLib {
 
         Real calculate(Real c_inf,
                        const ext::function<Real(Real)>& f,
-                       Real maxBound = Null<Real>()) const;
+                       const ext::function<Real()>& maxBound = {}) const;
+
+        Real calculate(Real c_inf,
+                       const ext::function<Real(Real)>& f,
+                       Real maxBound) const;
 
         Size numberOfEvaluations() const;
         bool isAdaptiveIntegration() const;
@@ -195,11 +235,9 @@ namespace QuantLib {
               GaussLaguerre, GaussLegendre,
               GaussChebyshev, GaussChebyshev2nd };
 
-        Integration(Algorithm intAlgo,
-                    const ext::shared_ptr<GaussianQuadrature>& quadrature);
+        Integration(Algorithm intAlgo, ext::shared_ptr<GaussianQuadrature> quadrature);
 
-        Integration(Algorithm intAlgo,
-                    const ext::shared_ptr<Integrator>& integrator);
+        Integration(Algorithm intAlgo, ext::shared_ptr<Integrator> integrator);
 
         const Algorithm intAlgo_;
         const ext::shared_ptr<Integrator> integrator_;
