@@ -461,8 +461,6 @@ namespace {
     template <class Engine>
     void testFdGreeks() {
 
-        SavedSettings backup;
-
         std::map<std::string,Real> calculated, expected, tolerance;
         tolerance["delta"]  = 7.0e-4;
         tolerance["gamma"]  = 2.0e-4;
@@ -579,8 +577,6 @@ void AmericanOptionTest::testFdShoutGreeks() {
 void AmericanOptionTest::testFDShoutNPV() {
     BOOST_TEST_MESSAGE("Testing finite-differences shout option pricing...");
 
-    SavedSettings backup;
-
     const auto dc = Actual365Fixed();
     const auto today = Date(4, February, 2021);
     Settings::instance().evaluationDate() = today;
@@ -638,8 +634,6 @@ void AmericanOptionTest::testFDShoutNPV() {
 void AmericanOptionTest::testZeroVolFDShoutNPV() {
     BOOST_TEST_MESSAGE("Testing zero volatility shout option pricing with discrete dividends...");
 
-    SavedSettings backup;
-
     const auto dc = Actual365Fixed();
     const auto today = Date(14, February, 2021);
     Settings::instance().evaluationDate() = today;
@@ -719,8 +713,6 @@ void AmericanOptionTest::testZeroVolFDShoutNPV() {
 void AmericanOptionTest::testLargeDividendShoutNPV() {
     BOOST_TEST_MESSAGE("Testing zero strike shout option pricing with discrete dividends...");
 
-    SavedSettings backup;
-
     const auto dc = Actual365Fixed();
     const auto today = Date(21, February, 2021);
     Settings::instance().evaluationDate() = today;
@@ -803,8 +795,6 @@ void AmericanOptionTest::testLargeDividendShoutNPV() {
 void AmericanOptionTest::testEscrowedVsSpotAmericanOption() {
     BOOST_TEST_MESSAGE("Testing escrowed vs spot dividend model for American options...");
 
-    SavedSettings backup;
-
     const auto dc = Actual360();
     const auto today = Date(27, February, 2021);
     Settings::instance().evaluationDate() = today;
@@ -877,8 +867,6 @@ void AmericanOptionTest::testEscrowedVsSpotAmericanOption() {
 void AmericanOptionTest::testTodayIsDividendDate() {
     BOOST_TEST_MESSAGE("Testing escrowed vs spot dividend model on dividend dates for American options...");
 
-    SavedSettings backup;
-
     const auto dc = Actual360();
     const auto today = Date(27, February, 2021);
     Settings::instance().evaluationDate() = today;
@@ -1000,8 +988,6 @@ void AmericanOptionTest::testCallPutParity() {
 
     // R.L. McDonald, M.D. Schroder: A parity result for American option
 
-    SavedSettings backup;
-
     const DayCounter dc = Actual365Fixed();
     const Date today = Date(8, April, 2022);
     Settings::instance().evaluationDate() = today;
@@ -1204,8 +1190,6 @@ void AmericanOptionTest::testQdPlusBoundaryConvergence() {
 void AmericanOptionTest::testQdAmericanEngines() {
     BOOST_TEST_MESSAGE("Testing QD+ American option pricing...");
 
-    SavedSettings backup;
-
     const DayCounter dc = Actual365Fixed();
     const Date today = Date(1, June, 2022);
     Settings::instance().evaluationDate() = today;
@@ -1480,8 +1464,6 @@ void AmericanOptionTest::testAndersenLakeHighPrecisionExample() {
     BOOST_TEST_MESSAGE("Testing Andersen, Lake and Offengenden "
                         "high precision example...");
 
-    SavedSettings backup;
-
     // Example and results are taken from
     //    Leif Andersen, Mark Lake and Dimitri Offengenden (2015)
     //    "High Performance American Option Pricing",
@@ -1579,8 +1561,6 @@ void AmericanOptionTest::testQdEngineStandardExample() {
     BOOST_TEST_MESSAGE("Testing Andersen, Lake and Offengenden "
                         "standard example...");
 
-    SavedSettings backup;
-
     const DayCounter dc = Actual365Fixed();
     const Date today = Date(1, June, 2022);
     Settings::instance().evaluationDate() = today;
@@ -1678,8 +1658,6 @@ void AmericanOptionTest::testBulkQdFpAmericanEngine() {
     //    "High Performance American Option Pricing",
     //    https://papers.ssrn.com/sol3/papers.cfm?abstract_id=2547027
 
-    SavedSettings backup;
-
     const DayCounter dc = Actual365Fixed();
     const Date today = Date(1, June, 2022);
     Settings::instance().evaluationDate() = today;
@@ -1784,8 +1762,6 @@ void AmericanOptionTest::testQdEngineWithLobattoIntegral() {
     BOOST_TEST_MESSAGE("Testing Andersen, Lake and Offengenden "
                         "with high precision Gauss-Lobatto integration...");
 
-    SavedSettings backup;
-
     const DayCounter dc = Actual365Fixed();
     const Date today = Date(5, November, 2022);
     Settings::instance().evaluationDate() = today;
@@ -1854,8 +1830,6 @@ void AmericanOptionTest::testQdNegativeDividendYield() {
                         "with positive or zero interest rate and "
                         "negative dividend yield...");
 
-    SavedSettings backup;
-
     const DayCounter dc = Actual365Fixed();
     const Date today = Date(5, December, 2022);
     Settings::instance().evaluationDate() = today;
@@ -1926,8 +1900,6 @@ void AmericanOptionTest::testBjerksundStenslandEuropeanGreeks() {
     BOOST_TEST_MESSAGE("Testing Bjerksund-Stensland greeks when early "
                        "exercise is not optimal...");
 
-    SavedSettings backup;
-
     const Date today = Date(5, November, 2022);
     Settings::instance().evaluationDate() = today;
 
@@ -1987,7 +1959,7 @@ void AmericanOptionTest::testBjerksundStenslandEuropeanGreeks() {
         );
         europeanOption.setPricingEngine(europeanEngine);
 
-        const Real tol = 1000*QL_EPSILON;
+        constexpr double tol = 1000*QL_EPSILON;
 
         BOOST_CHECK_CLOSE(europeanOption.NPV(), americanOption.NPV(), tol);
         BOOST_CHECK_CLOSE(europeanOption.delta(), americanOption.delta(), tol);
@@ -2005,8 +1977,6 @@ void AmericanOptionTest::testBjerksundStenslandEuropeanGreeks() {
 void AmericanOptionTest::testBjerksundStenslandAmericanGreeks() {
     BOOST_TEST_MESSAGE("Testing Bjerksund-Stensland American greeks...");
 
-    SavedSettings backup;
-
     const Date today = Date(5, December, 2022);
     Settings::instance().evaluationDate() = today;
 
@@ -2198,8 +2168,6 @@ void AmericanOptionTest::testBjerksundStenslandAmericanGreeks() {
 void AmericanOptionTest::testSingleBjerksundStenslandGreeks() {
     BOOST_TEST_MESSAGE("Testing a single Bjerksund-Stensland greeks set...");
 
-    SavedSettings backup;
-
     const Date today = Date(20, January, 2023);
     Settings::instance().evaluationDate() = today;
 
@@ -2257,7 +2225,7 @@ void AmericanOptionTest::testSingleBjerksundStenslandGreeks() {
     const Real expectedTheta = -4.22540293840206704;
 
     const auto report = [=](Real value, Real expectedValue, const std::string& name) {
-        const Real tol = 1e6*QL_EPSILON;
+        constexpr double tol = 1e6*QL_EPSILON;
         const Real error = std::abs(value-expectedValue);
         if (error > tol)
             REPORT_FAILURE(name, \
