@@ -59,9 +59,6 @@ namespace cms_test {
         std::vector<ext::shared_ptr<CmsCouponPricer> > numericalPricers;
         std::vector<ext::shared_ptr<CmsCouponPricer> > analyticPricers;
 
-        // cleanup
-        SavedSettings backup;
-
         // setup
         CommonVars() {
 
@@ -205,8 +202,7 @@ namespace cms_test {
             bool isAtmCalibrated = false;
 
             SabrVolCube1 = Handle<SwaptionVolatilityStructure>(
-                ext::shared_ptr<SabrSwaptionVolatilityCube>(new
-                    SabrSwaptionVolatilityCube(atmVol,
+                ext::make_shared<SabrSwaptionVolatilityCube>(atmVol,
                                      optionTenors,
                                      swapTenors,
                                      strikeSpreads,
@@ -216,7 +212,7 @@ namespace cms_test {
                                      vegaWeightedSmileFit,
                                      guess,
                                      isParameterFixed,
-                                     isAtmCalibrated)));
+                                     isAtmCalibrated));
             SabrVolCube1->enableExtrapolation();
 
             yieldCurveModels = {GFunctionFactory::Standard,
@@ -250,7 +246,7 @@ namespace cms_test {
 
 void CmsTest::testFairRate()  {
 
-    BOOST_TEST_MESSAGE("Testing Hagan-pricer flat-vol equivalence for coupons...");
+    BOOST_TEST_MESSAGE("Testing Hagan-pricer flat-vol equivalence for coupons (lognormal case)...");
 
     using namespace cms_test;
 
@@ -316,7 +312,7 @@ void CmsTest::testFairRate()  {
 
 void CmsTest::testCmsSwap() {
 
-    BOOST_TEST_MESSAGE("Testing Hagan-pricer flat-vol equivalence for swaps...");
+    BOOST_TEST_MESSAGE("Testing Hagan-pricer flat-vol equivalence for swaps (lognormal case)...");
 
     using namespace cms_test;
 
@@ -379,7 +375,7 @@ void CmsTest::testCmsSwap() {
 
 void CmsTest::testParity() {
 
-    BOOST_TEST_MESSAGE("Testing put-call parity for capped-floored CMS coupons...");
+    BOOST_TEST_MESSAGE("Testing put-call parity for capped-floored CMS coupons (lognormal case)...");
 
     using namespace cms_test;
 
