@@ -20,12 +20,12 @@
 
 #include "convertiblebonds.hpp"
 #include "utilities.hpp"
-#include <ql/experimental/convertiblebonds/convertiblebond.hpp>
-#include <ql/experimental/convertiblebonds/binomialconvertibleengine.hpp>
+#include <ql/instruments/bonds/convertiblebonds.hpp>
 #include <ql/instruments/bonds/zerocouponbond.hpp>
 #include <ql/instruments/bonds/fixedratebond.hpp>
 #include <ql/instruments/bonds/floatingratebond.hpp>
 #include <ql/instruments/vanillaoption.hpp>
+#include <ql/pricingengines/bond/binomialconvertibleengine.hpp>
 #include <ql/pricingengines/vanilla/binomialengine.hpp>
 #include <ql/time/calendars/target.hpp>
 #include <ql/time/calendars/unitedstates.hpp>
@@ -63,13 +63,9 @@ namespace convertible_bonds_test {
         RelinkableHandle<Quote> creditSpread;
 
         CallabilitySchedule no_callability;
-        DividendSchedule no_dividends;
 
         Real faceAmount, redemption, conversionRatio;
 
-        // cleanup
-        SavedSettings backup;
-
         // setup
         CommonVars() {
             calendar = TARGET();
@@ -129,12 +125,13 @@ void ConvertibleBondTest::testBond() {
 
     Size timeSteps = 1001;
     ext::shared_ptr<PricingEngine> engine =
-        ext::make_shared<BinomialConvertibleEngine<CoxRossRubinstein> >(
-            vars.process, timeSteps);
+        ext::make_shared<BinomialConvertibleEngine<CoxRossRubinstein> >(vars.process,
+            timeSteps, 
+            vars.creditSpread);
 
     Handle<YieldTermStructure> discountCurve(
          ext::make_shared<ForwardSpreadedTermStructure>(vars.riskFreeRate,
-                                                          vars.creditSpread));
+                                                        vars.creditSpread));
 
     // zero-coupon
 
@@ -146,16 +143,14 @@ void ConvertibleBondTest::testBond() {
                       .backwards();
 
     ConvertibleZeroCouponBond euZero(euExercise, vars.conversionRatio,
-                                     vars.no_dividends, vars.no_callability,
-                                     vars.creditSpread,
+                                     vars.no_callability,
                                      vars.issueDate, vars.settlementDays,
                                      vars.dayCounter, schedule,
                                      vars.redemption);
     euZero.setPricingEngine(engine);
 
     ConvertibleZeroCouponBond amZero(amExercise, vars.conversionRatio,
-                                     vars.no_dividends, vars.no_callability,
-                                     vars.creditSpread,
+                                     vars.no_callability,
                                      vars.issueDate, vars.settlementDays,
                                      vars.dayCounter, schedule,
                                      vars.redemption);
@@ -198,16 +193,14 @@ void ConvertibleBondTest::testBond() {
                              .backwards();
 
     ConvertibleFixedCouponBond euFixed(euExercise, vars.conversionRatio,
-                                       vars.no_dividends, vars.no_callability,
-                                       vars.creditSpread,
+                                       vars.no_callability,
                                        vars.issueDate, vars.settlementDays,
                                        coupons, vars.dayCounter,
                                        schedule, vars.redemption);
     euFixed.setPricingEngine(engine);
 
     ConvertibleFixedCouponBond amFixed(amExercise, vars.conversionRatio,
-                                       vars.no_dividends, vars.no_callability,
-                                       vars.creditSpread,
+                                       vars.no_callability,
                                        vars.issueDate, vars.settlementDays,
                                        coupons, vars.dayCounter,
                                        schedule, vars.redemption);
@@ -246,8 +239,7 @@ void ConvertibleBondTest::testBond() {
     std::vector<Rate> spreads;
 
     ConvertibleFloatingRateBond euFloating(euExercise, vars.conversionRatio,
-                                           vars.no_dividends, vars.no_callability,
-                                           vars.creditSpread,
+                                           vars.no_callability,
                                            vars.issueDate, vars.settlementDays,
                                            index, fixingDays, spreads,
                                            vars.dayCounter, schedule,
@@ -255,8 +247,7 @@ void ConvertibleBondTest::testBond() {
     euFloating.setPricingEngine(engine);
 
     ConvertibleFloatingRateBond amFloating(amExercise, vars.conversionRatio,
-                                           vars.no_dividends, vars.no_callability,
-                                           vars.creditSpread,
+                                           vars.no_callability,
                                            vars.issueDate, vars.settlementDays,
                                            index, fixingDays, spreads,
                                            vars.dayCounter, schedule,
@@ -321,10 +312,10 @@ void ConvertibleBondTest::testOption() {
     Size timeSteps = 2001;
     ext::shared_ptr<PricingEngine> engine =
         ext::make_shared<BinomialConvertibleEngine<CoxRossRubinstein> >(
-                                                     vars.process, timeSteps);
+            vars.process, timeSteps, vars.creditSpread);
     ext::shared_ptr<PricingEngine> vanillaEngine =
         ext::make_shared<BinomialVanillaEngine<CoxRossRubinstein> >(
-                                                     vars.process, timeSteps);
+            vars.process, timeSteps);
 
     vars.creditSpread.linkTo(ext::make_shared<SimpleQuote>(0.0));
 
@@ -339,8 +330,7 @@ void ConvertibleBondTest::testOption() {
                                       .backwards();
 
     ConvertibleZeroCouponBond euZero(euExercise, vars.conversionRatio,
-                                     vars.no_dividends, vars.no_callability,
-                                     vars.creditSpread,
+                                     vars.no_callability,
                                      vars.issueDate, vars.settlementDays,
                                      vars.dayCounter, schedule,
                                      vars.redemption);
@@ -369,8 +359,6 @@ void ConvertibleBondTest::testRegression() {
     BOOST_TEST_MESSAGE(
        "Testing fixed-coupon convertible bond in known regression case...");
 
-    SavedSettings backup;
-
     Date today = Date(23, December, 2008);
     Date tomorrow = today + 1;
 
@@ -437,13 +425,12 @@ void ConvertibleBondTest::testRegression() {
     Real redemption = 100.0;
 
     ConvertibleFixedCouponBond bond(exercise, conversionRatio,
-                                    no_dividends, no_callability,
-                                    spread, issueDate, settlementDays,
+                                    no_callability,
+                                    issueDate, settlementDays,
                                     coupons, dayCounter,
                                     schedule, redemption);
-    bond.setPricingEngine(
-        ext::make_shared<BinomialConvertibleEngine<CoxRossRubinstein> >(
-                                                              process, 600));
+    bond.setPricingEngine(ext::make_shared<BinomialConvertibleEngine<CoxRossRubinstein> >(
+        process, 600, spread, no_dividends));
 
     try {
         Real x = bond.NPV();  // should throw; if not, an INF was not detected.
