@@ -32,9 +32,8 @@
 #include <ql/time/asx.hpp>
 #include <ql/utilities/dataparsers.hpp>
 
-#include <boost/unordered_set.hpp>
-#include <boost/functional/hash.hpp>
 #include <sstream>
+#include <unordered_set>
 
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
@@ -406,6 +405,23 @@ void DateTest::intraday() {
     BOOST_CHECK_MESSAGE(s.str() == std::string("2015-02-07T01:04:02,003004"),
         "datetime to string failed to reproduce expected result");
 
+    const Date d3 = Date(10, April, 2023, 11, 43, 13, 234, 253);
+
+    BOOST_CHECK_MESSAGE(d3 + Period(23, Hours) ==
+            Date(11, April, 2023, 10, 43, 13, 234, 253), "failed to add hours");
+
+    BOOST_CHECK_MESSAGE(d3 + Period(2, Minutes) ==
+            Date(10, April, 2023, 11, 45, 13, 234, 253), "failed to add minutes");
+
+    BOOST_CHECK_MESSAGE(d3 + Period(-2, Seconds) ==
+            Date(10, April, 2023, 11, 43, 11, 234, 253), "failed to add seconds");
+
+    BOOST_CHECK_MESSAGE(d3 + Period(-20, Milliseconds) ==
+            Date(10, April, 2023, 11, 43, 13, 214, 253), "failed to add milliseconds");
+
+    BOOST_CHECK_MESSAGE(d3 + Period(20, Microseconds) ==
+            Date(10, April, 2023, 11, 43, 13, 234, 273), "failed to add microseconds");
+
 #endif
 }
 
@@ -415,7 +431,7 @@ void DateTest::canHash() {
     Date start_date = Date(1, Jan, 2020);
     int nb_tests = 500;
 
-    boost::hash<Date> hasher;
+    std::hash<Date> hasher;
 
     // Check hash values
     for (int i = 0; i < nb_tests; ++i) {
@@ -442,7 +458,7 @@ void DateTest::canHash() {
     }
 
     // Check if Date can be used as unordered_set key
-    boost::unordered_set<Date> set;
+    std::unordered_set<Date> set;
     set.insert(start_date);
 
     if (set.count(start_date) == 0) {
@@ -450,6 +466,7 @@ void DateTest::canHash() {
     }
 }
 
+
 test_suite* DateTest::suite(SpeedLevel speed) {
     auto* suite = BOOST_TEST_SUITE("Date tests");
 
@@ -461,7 +478,9 @@ test_suite* DateTest::suite(SpeedLevel speed) {
     #ifndef QL_PATCH_SOLARIS
     suite->add(QUANTLIB_TEST_CASE(&DateTest::parseDates));
     #endif
+    #ifdef QL_HIGH_RESOLUTION_DATE
     suite->add(QUANTLIB_TEST_CASE(&DateTest::intraday));
+    #endif
     suite->add(QUANTLIB_TEST_CASE(&DateTest::canHash));
 
     return suite;
