@@ -26,6 +26,9 @@
 #include <ql/time/daycounters/actual360.hpp>
 #include <ql/time/daycounters/actualactual.hpp>
 #include <ql/time/daycounters/actual365fixed.hpp>
+#include <ql/time/daycounters/actual36525.hpp>
+#include <ql/time/daycounters/actual366.hpp>
+#include <ql/time/daycounters/actual364.hpp>
 #include <ql/time/daycounters/one.hpp>
 #include <ql/time/daycounters/simpledaycounter.hpp>
 #include <ql/time/daycounters/business252.hpp>
@@ -35,9 +38,12 @@
 #include <ql/time/calendars/canada.hpp>
 #include <ql/time/calendars/unitedstates.hpp>
 #include <ql/time/schedule.hpp>
+#include <ql/math/comparison.hpp>
+#include <ql/time/calendars/china.hpp>
+#include <ql/time/daycounters/yearfractiontodate.hpp>
+
 #include <cmath>
 #include <iomanip>
-#include <ql/time/calendars/china.hpp>
 
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
@@ -54,11 +60,10 @@ namespace day_counters_test {
             : convention(convention), start(start), end(end),
             refStart(refStart), refEnd(refEnd), result(result) {}
         SingleCase(ActualActual::Convention convention,
-            const Date& start,
-            const Date& end,
-            Time result)
-            : convention(convention), start(start), end(end),
-            refStart(Date()), refEnd(Date()), result(result) {}
+                   const Date& start,
+                   const Date& end,
+                   Time result)
+        : convention(convention), start(start), end(end), result(result) {}
         ActualActual::Convention convention;
         Date start;
         Date end;
@@ -1026,7 +1031,7 @@ void DayCounterTest::testActual365_Canadian() {
 void DayCounterTest::testIntraday() {
 #ifdef QL_HIGH_RESOLUTION_DATE
 
-    BOOST_TEST_MESSAGE("Testing intraday behavior of day counter ...");
+    BOOST_TEST_MESSAGE("Testing intraday behavior of day counter...");
 
     const Date d1(12, February, 2015);
     const Date d2(14, February, 2015, 12, 34, 17, 1, 230298);
@@ -1053,6 +1058,8 @@ void DayCounterTest::testIntraday() {
 }
 
 void DayCounterTest::testActualActualOutOfScheduleRange() {
+    BOOST_TEST_MESSAGE("Testing usage of actual/actual out of schedule...");
+
     Date today = Date(10, November, 2020);
     Date temp = Settings::instance().evaluationDate();
     Settings::instance().evaluationDate() = today;
@@ -1084,16 +1091,247 @@ void DayCounterTest::testActualActualOutOfScheduleRange() {
     Settings::instance().evaluationDate() = temp;
 }
 
+
+void DayCounterTest::testAct366() {
+
+    BOOST_TEST_MESSAGE("Testing Act/366 day counter...");
+
+    std::vector<Date> testDates = {
+        Date(1, February, 2002),
+        Date(4, February, 2002),
+        Date(16, May, 2003),
+        Date(17, December, 2003),
+        Date(17, December, 2004),
+        Date(19, December, 2005),
+        Date(2, January, 2006),
+        Date(13, March, 2006),
+        Date(15, May, 2006),
+        Date(17, March, 2006),
+        Date(15, May, 2006),
+        Date(26, July, 2006),
+        Date(28, June, 2007),
+        Date(16, September, 2009),
+        Date(26, July, 2016)
+    };
+
+    Time expected[] = {
+        0.00819672131147541,
+        1.27322404371585,
+        0.587431693989071,
+        1.0000000000000,
+        1.00273224043716,
+        0.0382513661202186,
+        0.191256830601093,
+        0.172131147540984,
+        -0.16120218579235,
+        0.16120218579235,
+        0.19672131147541,
+        0.920765027322404,
+        2.21584699453552,
+        6.84426229508197
+        };
+
+    DayCounter dayCounter = Actual366();
+
+    Time calculated;
+
+    for (Size i=1; i<testDates.size(); i++) {
+        calculated = dayCounter.yearFraction(testDates[i-1],testDates[i]);
+        if (std::fabs(calculated-expected[i-1]) > 1.0e-12) {
+                BOOST_ERROR("from " << testDates[i-1]
+                            << " to " << testDates[i] << ":\n"
+                            << std::setprecision(14)
+                            << "    calculated: " << calculated << "\n"
+                            << "    expected:   " << expected[i-1]);
+        }
+    }
+}
+
+void DayCounterTest::testAct36525() {
+
+    BOOST_TEST_MESSAGE("Testing Act/365.25 day counter...");
+
+    std::vector<Date> testDates = {
+        Date(1, February, 2002),
+        Date(4, February, 2002),
+        Date(16, May, 2003),
+        Date(17, December, 2003),
+        Date(17, December, 2004),
+        Date(19, December, 2005),
+        Date(2, January, 2006),
+        Date(13, March, 2006),
+        Date(15, May, 2006),
+        Date(17, March, 2006),
+        Date(15, May, 2006),
+        Date(26, July, 2006),
+        Date(28, June, 2007),
+        Date(16, September, 2009),
+        Date(26, July, 2016)
+    };
+
+    Time expected[] = {
+        0.0082135523613963,
+        1.27583846680356,
+        0.588637919233402,
+        1.00205338809035,
+        1.00479123887748,
+        0.0383299110198494,
+        0.191649555099247,
+        0.172484599589322,
+        -0.161533196440794,
+        0.161533196440794,
+        0.197125256673511,
+        0.922655715263518,
+        2.22039698836413,
+        6.85831622176591
+        };
+
+    DayCounter dayCounter = Actual36525();
+
+    Time calculated;
+
+    for (Size i=1; i<testDates.size(); i++) {
+        calculated = dayCounter.yearFraction(testDates[i-1],testDates[i]);
+        if (std::fabs(calculated-expected[i-1]) > 1.0e-12) {
+                BOOST_ERROR("from " << testDates[i-1]
+                            << " to " << testDates[i] << ":\n"
+                            << std::setprecision(14)
+                            << "    calculated: " << calculated << "\n"
+                            << "    expected:   " << expected[i-1]);
+        }
+    }
+}
+
+
+void DayCounterTest::testActualConsistency() {
+    BOOST_TEST_MESSAGE("Testing consistency between different actual day-counters...");
+
+    const std::vector<Date> todayDates = {
+            Date(12, January, 2022)
+#ifdef QL_HIGH_RESOLUTION_DATE
+            ,
+            Date(7, February, 2022, 11, 43, 12, 293, 32)
+#endif
+    };
+
+    const std::vector<Date> testDates = {
+        Date(1, February, 2023), Date(4, February, 2023), Date(16, May, 2024),
+        Date(17, December, 2024),Date(17, December, 2025), Date(19, December, 2026),
+        Date(2, January, 2027), Date(13, March, 2028), Date(15, May, 2028),
+        Date(26, July, 2036)
+#ifdef QL_HIGH_RESOLUTION_DATE
+        ,
+        Date(23, August, 2025, 18, 1, 22, 927, 832),
+        Date(23, August, 2032, 2, 23, 22, 0, 636)
+#endif
+    };
+
+    const DayCounter actual365 = Actual365Fixed();
+    const DayCounter actual366 = Actual366();
+    const DayCounter actual364 = Actual364();
+    const DayCounter actual36525 = Actual36525();
+    const DayCounter actual360 = Actual360();
+    const DayCounter actual360incl = Actual360(true);
+
+    for (const auto& today: todayDates)
+        for (const auto& d: testDates) {
+            const Time t365 = actual365.yearFraction(today, d);
+            const Time t366 = actual366.yearFraction(today, d);
+            const Time t364 = actual364.yearFraction(today, d);
+            const Time t360 = actual360.yearFraction(today, d);
+            const Time t360incl = actual360incl.yearFraction(today, d);
+            const Time t36525 = actual36525.yearFraction(today, d);
+
+            QL_CHECK_SMALL(t365*365/366.0 - t366, 1e-14);
+            QL_CHECK_SMALL(t365*365/364.0 - t364, 1e-14);
+            QL_CHECK_SMALL(t365*365/360.0 - t360, 1e-14);
+            QL_CHECK_SMALL(t365*365/364.0 - t364, 1e-14);
+            QL_CHECK_SMALL(t365*365/365.25 - t36525, 1e-14);
+            QL_CHECK_SMALL(t365*365/360.0 - (t360incl*360-1)/360, 1e-14);
+        }
+}
+
+
+void DayCounterTest::testYearFraction2DateBulk() {
+    BOOST_TEST_MESSAGE("Testing bulk dates for YearFractionToDate ...");
+
+    const auto dayCounters = std::vector<DayCounter>{
+        Actual365Fixed(),
+        Actual365Fixed(Actual365Fixed::NoLeap),
+        Actual360(), Actual360(true),
+        Actual36525(), Actual36525(true),
+        Actual364(),
+        Actual366(), Actual366(true),
+        ActualActual(ActualActual::ISDA),
+        ActualActual(ActualActual::ISMA),
+        ActualActual(ActualActual::Bond),
+        ActualActual(ActualActual::Historical),
+        ActualActual(ActualActual::Actual365),
+        ActualActual(ActualActual::AFB),
+        ActualActual(ActualActual::Euro),
+        Business252(),
+        Thirty360(Thirty360::USA),
+        Thirty360(Thirty360::BondBasis),
+        Thirty360(Thirty360::European),
+        Thirty360(Thirty360::EurobondBasis),
+        Thirty360(Thirty360::Italian),
+        Thirty360(Thirty360::German),
+        Thirty360(Thirty360::ISMA),
+        Thirty360(Thirty360::ISDA),
+        Thirty360(Thirty360::NASD),
+        Thirty365(),
+        SimpleDayCounter()
+    };
+
+    for (const auto& dc : dayCounters)
+        for (Integer i=-360; i < 730; ++i) {
+            const Date today = Date(1, January, 2020) + Period(i, Days);
+            const Date target = today + Period(i, Days);
+
+            const Time t = dc.yearFraction(today, target);
+            const Date time2Date = yearFractionToDate(dc, today, t);
+            const Time tNew = dc.yearFraction(today, time2Date);
+
+            if (!close_enough(t, tNew)) {
+                BOOST_FAIL(
+                       "\ntoday      : " << today
+                    << "\ntarget     : " << target
+                    << "\ninverse    : " << time2Date
+                    << "\ntime diff  : " << t - tNew
+                    << "\nday counter: " << dc.name()
+                );
+            }
+        }
+}
+
+void DayCounterTest::testYearFraction2DateRounding() {
+    BOOST_TEST_MESSAGE("Testing YearFractionToDate rounding to closer date...");
+
+    const std::vector<DayCounter> dayCounters
+        = {Thirty360(Thirty360::USA), Actual360()};
+    const Date d1(1, February, 2023), d2(17, February, 2124);
+
+    for (const DayCounter& dc : dayCounters) {
+        Time t = dc.yearFraction(d1, d2);
+        for (Time offset = 0; offset < 1 + 1e-10; offset+=0.05) {
+            const Date inv = yearFractionToDate(dc, d1, t + offset/360);
+            if (offset < 0.4999)
+                BOOST_CHECK_EQUAL(inv, d2);
+            else
+                BOOST_CHECK_EQUAL(inv, d2 + Period(1, Days));
+        }
+    }
+}
+
+
+
 test_suite* DayCounterTest::suite() {
     auto* suite = BOOST_TEST_SUITE("Day counter tests");
     suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testActualActual));
     suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testActualActualIsma));
-    suite->add(QUANTLIB_TEST_CASE(
-                    &DayCounterTest::testActualActualWithSemiannualSchedule));
-    suite->add(QUANTLIB_TEST_CASE(
-                        &DayCounterTest::testActualActualWithAnnualSchedule));
-    suite->add(QUANTLIB_TEST_CASE(
-                              &DayCounterTest::testActualActualWithSchedule));
+    suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testActualActualWithSemiannualSchedule));
+    suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testActualActualWithAnnualSchedule));
+    suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testActualActualWithSchedule));
     suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testSimple));
     suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testOne));
     suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testBusiness252));
@@ -1103,6 +1341,11 @@ test_suite* DayCounterTest::suite() {
     suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testThirty360_ISDA));
     suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testActual365_Canadian));
     suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testActualActualOutOfScheduleRange));
+    suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testAct366));
+    suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testAct36525));
+    suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testActualConsistency));
+    suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testYearFraction2DateBulk));
+    suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testYearFraction2DateRounding));
 
 #ifdef QL_HIGH_RESOLUTION_DATE
     suite->add(QUANTLIB_TEST_CASE(&DayCounterTest::testIntraday));
