@@ -60,8 +60,6 @@ void HybridHestonHullWhiteProcessTest::testBsmHullWhiteEngine() {
     BOOST_TEST_MESSAGE("Testing European option pricing for a BSM process"
                        " with one-factor Hull-White model...");
 
-    SavedSettings backup;
-
     DayCounter dc = Actual365Fixed();
 
     const Date today = Date::todaysDate();
@@ -156,8 +154,6 @@ void HybridHestonHullWhiteProcessTest::testCompareBsmHWandHestonHW() {
     BOOST_TEST_MESSAGE("Comparing European option pricing for a BSM process"
                        " with one-factor Hull-White model...");
 
-    SavedSettings backup;
-
     DayCounter dc = Actual365Fixed();
 
     const Date today = Date::todaysDate();
@@ -248,8 +244,6 @@ void HybridHestonHullWhiteProcessTest::testCompareBsmHWandHestonHW() {
 void HybridHestonHullWhiteProcessTest::testZeroBondPricing() {
     BOOST_TEST_MESSAGE("Testing Monte-Carlo zero bond pricing...");
 
-    SavedSettings backup;
-
     DayCounter dc = Actual360();
     const Date today = Date::todaysDate();
 
@@ -365,8 +359,6 @@ void HybridHestonHullWhiteProcessTest::testZeroBondPricing() {
 void HybridHestonHullWhiteProcessTest::testMcVanillaPricing() {
     BOOST_TEST_MESSAGE("Testing Monte-Carlo vanilla option pricing...");
 
-    SavedSettings backup;
-
     DayCounter dc = Actual360();
     const Date today = Date::todaysDate();
 
@@ -454,8 +446,6 @@ void HybridHestonHullWhiteProcessTest::testMcVanillaPricing() {
 void HybridHestonHullWhiteProcessTest::testMcPureHestonPricing() {
     BOOST_TEST_MESSAGE("Testing Monte-Carlo Heston option pricing...");
 
-    SavedSettings backup;
-
     DayCounter dc = Actual360();
     const Date today = Date::todaysDate();
 
@@ -539,8 +529,6 @@ void HybridHestonHullWhiteProcessTest::testMcPureHestonPricing() {
 void HybridHestonHullWhiteProcessTest::testAnalyticHestonHullWhitePricing() {
     BOOST_TEST_MESSAGE("Testing analytic Heston Hull-White option pricing...");
 
-    SavedSettings backup;
-
     DayCounter dc = Actual360();
     const Date today = Date::todaysDate();
 
@@ -624,8 +612,6 @@ void HybridHestonHullWhiteProcessTest::testAnalyticHestonHullWhitePricing() {
 void HybridHestonHullWhiteProcessTest::testCallableEquityPricing() {
     BOOST_TEST_MESSAGE("Testing the pricing of a callable equity product...");
 
-    SavedSettings backup;
-
     /*
        For the definition of the example product see
        Alexander Giese, On the Pricing of Auto-Callable Equity
@@ -738,8 +724,6 @@ void HybridHestonHullWhiteProcessTest::testDiscretizationError() {
     BOOST_TEST_MESSAGE("Testing the discretization error of the "
                        "Heston Hull-White process...");
 
-    SavedSettings backup;
-
     DayCounter dc = Actual360();
     const Date today = Date::todaysDate();
 
@@ -824,8 +808,6 @@ void HybridHestonHullWhiteProcessTest::testDiscretizationError() {
 void HybridHestonHullWhiteProcessTest::testFdmHestonHullWhiteEngine() {
     BOOST_TEST_MESSAGE("Testing the FDM Heston Hull-White engine...");
 
-    SavedSettings backup;
-
     const Date today = Date(28, March, 2004);
     Settings::instance().evaluationDate() = today;
     const Date exerciseDate = Date(28, March, 2012);
@@ -996,8 +978,6 @@ void HybridHestonHullWhiteProcessTest::testBsmHullWhitePricing() {
 
     using namespace hybrid_heston_hullwhite_process_test;
 
-    SavedSettings backup;
-
     Date today(27, December, 2004);
     Settings::instance().evaluationDate() = today;
 
@@ -1084,8 +1064,6 @@ void HybridHestonHullWhiteProcessTest::testSpatialDiscretizatinError() {
 
     using namespace hybrid_heston_hullwhite_process_test;
 
-    SavedSettings backup;
-
     Date today(27, December, 2004);
     Settings::instance().evaluationDate() = today;
 
@@ -1182,8 +1160,6 @@ void HybridHestonHullWhiteProcessTest::testHestonHullWhiteCalibration() {
     //             \theta = 0.09, \sigma = 0.5, \rho=-0.75
     // Equity Short rate correlation: -0.5
 
-    SavedSettings backup;
-
     const DayCounter dc = Actual365Fixed();
     const Calendar calendar = TARGET();
     const Date today = Date(28, March, 2004);
@@ -1371,8 +1347,7 @@ void HybridHestonHullWhiteProcessTest::testHestonHullWhiteCalibration() {
 }
 
 void HybridHestonHullWhiteProcessTest::testH1HWPricingEngine() {
-
-    SavedSettings backup;
+    BOOST_TEST_MESSAGE("Testing the H1-HW approximation engine...");
 
     /*
      * Example taken from Lech Aleksander Grzelak,
