@@ -112,8 +112,6 @@ void LiborMarketModelTest::testSimpleCovarianceModels() {
 
     using namespace libor_market_model_test;
 
-    SavedSettings backup;
-
     const Size size = 10;
     const Real tolerance = 1e-14;
     Size i;
@@ -172,7 +170,7 @@ void LiborMarketModelTest::testSimpleCovarianceModels() {
 
         for (Size k=0; k<size; ++k) {
             Real expected = 0;
-            if (k>2*t) {
+            if (static_cast<Real>(k) > 2 * t) {
                 const Real T = fixingTimes[k];
                 expected=(a*(T-t)+d)*std::exp(-b*(T-t)) + c;
             }
@@ -191,14 +189,10 @@ void LiborMarketModelTest::testCapletPricing() {
 
     using namespace libor_market_model_test;
 
-    SavedSettings backup;
+    bool usingAtParCoupons  = IborCoupon::Settings::instance().usingAtParCoupons();
 
     const Size size = 10;
-    Real tolerance;
-    if (!IborCoupon::usingAtParCoupons())
-        tolerance = 1e-5;
-    else
-        tolerance = 1e-12;
+    Real tolerance = usingAtParCoupons ? 1e-12 : 1e-5;
 
     ext::shared_ptr<IborIndex> index = makeIndex();
     ext::shared_ptr<LiborForwardModelProcess> process(
@@ -227,13 +221,12 @@ void LiborMarketModelTest::testCapletPricing() {
     ext::shared_ptr<AnalyticCapFloorEngine> engine1(
                             new AnalyticCapFloorEngine(model, termStructure));
 
-    ext::shared_ptr<Cap> cap1(
-        new Cap(process->cashFlows(),
-                std::vector<Rate>(size, 0.04)));
-    cap1->setPricingEngine(engine1);
+    auto cap1 = Cap(process->cashFlows(),
+                    std::vector<Rate>(size, 0.04));
+    cap1.setPricingEngine(engine1);
 
     const Real expected = 0.015853935178;
-    const Real calculated = cap1->NPV();
+    const Real calculated = cap1.NPV();
 
     if (std::fabs(expected - calculated) > tolerance)
         BOOST_ERROR("Failed to reproduce npv"
@@ -246,8 +239,6 @@ void LiborMarketModelTest::testCalibration() {
 
     using namespace libor_market_model_test;
 
-    SavedSettings backup;
-
     const Size size = 14;
     const Real tolerance = 8e-3;
 
@@ -297,10 +288,10 @@ void LiborMarketModelTest::testCalibration() {
         Handle<Quote> capVol(
             ext::shared_ptr<Quote>(new SimpleQuote(capVols[i-2])));
 
-        ext::shared_ptr<BlackCalibrationHelper> caphelper(
-            new CapHelper(maturity, capVol, index, Annual,
-                          index->dayCounter(), true, termStructure,
-                          BlackCalibrationHelper::ImpliedVolError));
+        auto caphelper =
+            ext::make_shared<CapHelper>(maturity, capVol, index, Annual,
+                                        index->dayCounter(), true, termStructure,
+                                        BlackCalibrationHelper::ImpliedVolError);
 
         caphelper->setPricingEngine(ext::shared_ptr<PricingEngine>(
                            new AnalyticCapFloorEngine(model, termStructure)));
@@ -315,12 +306,12 @@ void LiborMarketModelTest::testCalibration() {
                     ext::shared_ptr<Quote>(
                         new SimpleQuote(swaptionVols[swapVolIndex++])));
 
-                ext::shared_ptr<BlackCalibrationHelper> swaptionHelper(
-                    new SwaptionHelper(maturity, len, swaptionVol, index,
-                                       index->tenor(), dayCounter,
-                                       index->dayCounter(),
-                                       termStructure,
-                                       BlackCalibrationHelper::ImpliedVolError));
+                auto swaptionHelper =
+                    ext::make_shared<SwaptionHelper>(maturity, len, swaptionVol, index,
+                                                     index->tenor(), dayCounter,
+                                                     index->dayCounter(),
+                                                     termStructure,
+                                                     BlackCalibrationHelper::ImpliedVolError);
 
                 swaptionHelper->setPricingEngine(
                      ext::shared_ptr<PricingEngine>(
@@ -352,16 +343,12 @@ void LiborMarketModelTest::testSwaptionPricing() {
 
     using namespace libor_market_model_test;
 
-    SavedSettings backup;
+    bool usingAtParCoupons = IborCoupon::Settings::instance().usingAtParCoupons();
 
     const Size size  = 10;
     const Size steps = 8*size;
 
-    Real tolerance;
-    if (!IborCoupon::usingAtParCoupons())
-        tolerance = 1e-6;
-    else
-        tolerance = 1e-12;
+    Real tolerance = usingAtParCoupons ? 1e-12 : 1e-6;
 
     std::vector<Date> dates = {{4,September,2005}, {4,September,2011}};
     std::vector<Rate> rates = {0.04, 0.08};
@@ -452,8 +439,7 @@ void LiborMarketModelTest::testSwaptionPricing() {
                 ext::shared_ptr<Exercise> exercise(
                     new EuropeanExercise(process->fixingDates()[i]));
 
-                ext::shared_ptr<Swaption> swaption(
-                    new Swaption(forwardSwap, exercise));
+                auto swaption = ext::make_shared<Swaption>(forwardSwap, exercise);
                 swaption->setPricingEngine(engine);
 
                 GeneralStatistics stat;
