@@ -28,8 +28,8 @@
 #include <ql/termstructures/volatility/optionlet/strippedoptionletadapter.hpp>
 #include <ql/termstructures/yield/flatforward.hpp>
 #include <ql/time/calendars/nullcalendar.hpp>
-#include <utility>
-
+#include <chrono>
+#include <thread>
 
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
@@ -46,7 +46,7 @@ namespace {
         Size counter_ = 0;
     };
 
-    class RestoreUpdates {
+    class RestoreUpdates { // NOLINT(cppcoreguidelines-special-member-functions)
       public:
         ~RestoreUpdates() {
             ObservableSettings::instance().enableUpdates();
@@ -110,10 +110,9 @@ void ObservableTest::testObservableSettings() {
 
 #ifdef QL_ENABLE_THREAD_SAFE_OBSERVER_PATTERN
 
-#include <boost/atomic.hpp>
-#include <boost/thread/locks.hpp>
-#include <boost/thread/mutex.hpp>
-#include <boost/thread/thread.hpp>
+#include <atomic>
+#include <mutex>
+#include <thread>
 #include <boost/date_time/posix_time/posix_time_types.hpp>
 
 #include <list>
@@ -135,18 +134,18 @@ namespace {
         static int instanceCounter() { return instanceCounter_; }
 
       private:
-        boost::atomic<int> counter_;
-        static boost::atomic<int> instanceCounter_;
+        std::atomic<int> counter_;
+        static std::atomic<int> instanceCounter_;
     };
 
-    boost::atomic<int> MTUpdateCounter::instanceCounter_(0);
+    std::atomic<int> MTUpdateCounter::instanceCounter_(0);
 
     class GarbageCollector {
       public:
         GarbageCollector() : terminate_(false) { }
 
         void addObj(const ext::shared_ptr<MTUpdateCounter>& updateCounter) {
-            boost::lock_guard<boost::mutex> lock(mutex_);
+            std::lock_guard<std::mutex> lock(mutex_);
             objList.push_back(updateCounter);
         }
 
@@ -154,20 +153,20 @@ namespace {
             while(!terminate_) {
                 Size objListSize;
                 {
-                    boost::lock_guard<boost::mutex> lock(mutex_);
+                    std::lock_guard<std::mutex> lock(mutex_);
                     objListSize = objList.size();
                 }
 
                 if (objListSize > 20) {
                     // trigger gc
                     while (objListSize > 0) {
-                        boost::lock_guard<boost::mutex> lock(mutex_);
+                        std::lock_guard<std::mutex> lock(mutex_);
                         objList.pop_front();
                         objListSize = objList.size();
                     }
                 }
 
-                boost::this_thread::sleep(boost::posix_time::milliseconds(2));
+                std::this_thread::sleep_for(std::chrono::milliseconds(2));
             }
             objList.clear();
         }
@@ -176,8 +175,8 @@ namespace {
             terminate_ = true;
         }
       private:
-        boost::mutex mutex_;
-        boost::atomic<bool> terminate_;
+        std::mutex mutex_;
+        std::atomic<bool> terminate_;
 
         std::list<ext::shared_ptr<MTUpdateCounter> > objList;
     };
@@ -195,7 +194,7 @@ void ObservableTest::testAsyncGarbagCollector() {
     const ext::shared_ptr<SimpleQuote> quote(new SimpleQuote(-1.0));
 
     GarbageCollector gc;
-    boost::thread workerThread(&GarbageCollector::run, &gc);
+    std::thread workerThread(&GarbageCollector::run, &gc);
 
     for (Size i=0; i < 10000; ++i) {
         const ext::shared_ptr<MTUpdateCounter> observer(new MTUpdateCounter);
@@ -224,7 +223,7 @@ void ObservableTest::testMultiThreadingGlobalSettings() {
     ObservableSettings::instance().disableUpdates(true);
 
     GarbageCollector gc;
-    boost::thread workerThread(&GarbageCollector::run, &gc);
+    std::thread workerThread(&GarbageCollector::run, &gc);
 
     typedef std::list<ext::shared_ptr<MTUpdateCounter> > local_list_type;
     local_list_type localList;
@@ -267,8 +266,8 @@ void ObservableTest::testMultiThreadingGlobalSettings() {
 #endif
 
 void ObservableTest::testDeepUpdate() {
+    BOOST_TEST_MESSAGE("Testing deep update of observers...");
 
-    SavedSettings backup;
     RestoreUpdates guard;
 
     Date refDate = Settings::instance().evaluationDate();
@@ -315,8 +314,6 @@ namespace {
 void ObservableTest::testEmptyObserverList() {
 	BOOST_TEST_MESSAGE("Testing unregisterWith call on empty observer...");
 
-    SavedSettings backup;
-
     const ext::shared_ptr<DummyObserver> dummyObserver=ext::make_shared<DummyObserver>();
     dummyObserver->unregisterWith(ext::make_shared<SimpleQuote>(10.0));
 }
