@@ -27,6 +27,7 @@
 #include <ql/termstructures/yield/piecewiseyieldcurve.hpp>
 #include <ql/termstructures/yield/flatforward.hpp>
 #include <ql/time/calendars/nullcalendar.hpp>
+#include <ql/time/calendars/target.hpp>
 #include <ql/time/daycounters/actual360.hpp>
 #include <ql/time/daycounters/thirty360.hpp>
 #include <ql/time/daycounters/actual365fixed.hpp>
@@ -50,8 +51,6 @@ using namespace boost::unit_test_framework;
 
 using std::exp;
 
-typedef PiecewiseYieldCurve<Discount,LogLinear> PiecewiseFlatForward;
-
 namespace overnight_indexed_swap_test {
 
     struct Datum {
@@ -130,9 +129,6 @@ namespace overnight_indexed_swap_test {
         ext::shared_ptr<IborIndex> swapIndex;
         RelinkableHandle<YieldTermStructure> swapTermStructure;
 
-        // cleanup
-        SavedSettings backup;
-
         // utilities
         ext::shared_ptr<OvernightIndexedSwap>
         makeSwap(Period length,
@@ -191,7 +187,7 @@ void OvernightIndexedSwapTest::testFairRate() {
     Spread spreads[] = { -0.001, -0.01, 0.0, 0.01, 0.001 };
 
     for (auto& length : lengths) {
-        for (double spread : spreads) {
+        for (Real spread : spreads) {
 
             ext::shared_ptr<OvernightIndexedSwap> swap = vars.makeSwap(length, 0.0, spread, false);
             ext::shared_ptr<OvernightIndexedSwap> swap2 = vars.makeSwap(length, 0.0, spread, true);
@@ -236,7 +232,7 @@ void OvernightIndexedSwapTest::testFairSpread() {
     Rate rates[] = { 0.04, 0.05, 0.06, 0.07 };
 
     for (auto& length : lengths) {
-        for (double j : rates) {
+        for (Real j : rates) {
 
             ext::shared_ptr<OvernightIndexedSwap> swap = vars.makeSwap(length, j, 0.0, false);
             ext::shared_ptr<OvernightIndexedSwap> swap2 = vars.makeSwap(length, j, 0.0, true);
@@ -351,8 +347,7 @@ namespace overnight_indexed_swap_test {
         eoniaHelpers.push_back(helper);
     }
 
-    ext::shared_ptr<PiecewiseFlatForward> eoniaTS(
-        new PiecewiseFlatForward (vars.today, eoniaHelpers, Actual365Fixed()));
+    auto eoniaTS = ext::make_shared<PiecewiseYieldCurve<Discount, LogLinear>>(vars.today, eoniaHelpers, Actual365Fixed());
 
     vars.eoniaTermStructure.linkTo(eoniaTS);
 
@@ -421,7 +416,7 @@ void OvernightIndexedSwapTest::testSeasonedSwaps() {
     vars.eoniaIndex->addFixing(Date(5,February,2009), 0.0013);
 
     for (auto& length : lengths) {
-        for (double spread : spreads) {
+        for (Real spread : spreads) {
 
             ext::shared_ptr<OvernightIndexedSwap> swap =
                 vars.makeSwap(length, 0.0, spread, false, effectiveDate);
@@ -444,8 +439,6 @@ void OvernightIndexedSwapTest::testBootstrapRegression() {
 
     using namespace overnight_indexed_swap_test;
 
-    SavedSettings backup;
-
     Datum data[] = {
         { 0,  1, Days,   0.0066   },
         { 2,  1, Weeks,  0.006445 },
@@ -500,13 +493,162 @@ void OvernightIndexedSwapTest::testBootstrapRegression() {
                                   Pillar::MaturityDate)));
     }
 
-    PiecewiseYieldCurve<Discount,LogCubic> curve(0, UnitedStates(), helpers, Actual365Fixed(),
-                                                 MonotonicLogCubic());
+    PiecewiseYieldCurve<Discount,LogCubic> curve(0, UnitedStates(UnitedStates::GovernmentBond),
+                                                 helpers, Actual365Fixed(), MonotonicLogCubic());
 
     BOOST_CHECK_NO_THROW(curve.discount(1.0));
 }
 
 
+void OvernightIndexedSwapTest::test131BootstrapRegression() {
+    BOOST_TEST_MESSAGE("Testing 1.31 regression with OIS bootstrap...");
+
+    Date today(11, December, 2012);
+    Settings::instance().evaluationDate() = today;
+
+    auto eonia = ext::make_shared<Eonia>();
+
+    std::vector<ext::shared_ptr<RateHelper>> helpers;
+    helpers.push_back(ext::make_shared<OISRateHelper>(2, 1 * Weeks, Handle<Quote>(ext::make_shared<SimpleQuote>(0.070/100)), eonia));
+    helpers.push_back(ext::make_shared<DatedOISRateHelper>(Date(16, January, 2013), Date(13, February, 2013), Handle<Quote>(ext::make_shared<SimpleQuote>(0.046/100)), eonia));
+
+    auto curve = PiecewiseYieldCurve<ForwardRate,BackwardFlat>(0, TARGET(), helpers, Actual365Fixed());
+    BOOST_CHECK_NO_THROW(curve.nodes());
+}
+
+void OvernightIndexedSwapTest::testConstructorsAndNominals() {
+    BOOST_TEST_MESSAGE("Testing different constructors for OIS...");
+
+    using namespace overnight_indexed_swap_test;
+
+    CommonVars vars;
+
+    Date spot = vars.calendar.advance(vars.today, 2*Days);
+    Real nominal = 100000.0;
+
+    // constant notional, same schedule
+
+    Schedule schedule = MakeSchedule()
+        .from(spot)
+        .to(vars.calendar.advance(spot, 2*Years))
+        .withCalendar(vars.calendar)
+        .withFrequency(Annual);
+
+    auto ois_1 = OvernightIndexedSwap(Swap::Payer,
+                                      nominal,
+                                      schedule,
+                                      0.03,
+                                      Actual360(),
+                                      vars.eoniaIndex);
+
+    BOOST_CHECK_EQUAL(ois_1.fixedSchedule().tenor(), 1*Years);
+    BOOST_CHECK_EQUAL(ois_1.overnightSchedule().tenor(), 1*Years);
+    BOOST_CHECK_EQUAL(ois_1.paymentFrequency(), Annual);
+
+    BOOST_CHECK_EQUAL(ois_1.nominal(), nominal);
+
+    BOOST_CHECK_EQUAL(ois_1.nominals().size(), Size(1));
+    BOOST_CHECK_EQUAL(ois_1.nominals()[0], nominal);
+
+    BOOST_CHECK_EQUAL(ois_1.fixedNominals().size(), Size(1));
+    BOOST_CHECK_EQUAL(ois_1.fixedNominals()[0], nominal);
+
+    BOOST_CHECK_EQUAL(ois_1.overnightNominals().size(), Size(1));
+    BOOST_CHECK_EQUAL(ois_1.overnightNominals()[0], nominal);
+
+    // amortizing notionals, same schedule
+
+    auto ois_2 = OvernightIndexedSwap(Swap::Payer,
+                                      { nominal, nominal/2 },
+                                      schedule,
+                                      0.03,
+                                      Actual360(),
+                                      vars.eoniaIndex);
+
+    BOOST_CHECK_EQUAL(ois_2.fixedSchedule().tenor(), 1*Years);
+    BOOST_CHECK_EQUAL(ois_2.overnightSchedule().tenor(), 1*Years);
+    BOOST_CHECK_EQUAL(ois_2.paymentFrequency(), Annual);
+
+    BOOST_CHECK_EXCEPTION(ois_2.nominal(), Error,
+                          ExpectedErrorMessage("nominal is not constant"));
+
+    BOOST_CHECK_EQUAL(ois_2.nominals().size(), Size(2));
+    BOOST_CHECK_EQUAL(ois_2.nominals()[0], nominal);
+    BOOST_CHECK_EQUAL(ois_2.nominals()[1], nominal/2);
+
+    BOOST_CHECK_EQUAL(ois_2.fixedNominals().size(), Size(2));
+    BOOST_CHECK_EQUAL(ois_2.fixedNominals()[0], nominal);
+    BOOST_CHECK_EQUAL(ois_2.fixedNominals()[1], nominal/2);
+
+    BOOST_CHECK_EQUAL(ois_2.overnightNominals().size(), Size(2));
+    BOOST_CHECK_EQUAL(ois_2.overnightNominals()[0], nominal);
+    BOOST_CHECK_EQUAL(ois_2.overnightNominals()[1], nominal/2);
+
+    // constant notional, different schedules
+
+    const Schedule& fixedSchedule = schedule;
+    Schedule overnightSchedule = MakeSchedule()
+        .from(spot)
+        .to(vars.calendar.advance(spot, 2*Years))
+        .withCalendar(vars.calendar)
+        .withFrequency(Semiannual);
+
+    auto ois_3 = OvernightIndexedSwap(Swap::Payer,
+                                      nominal,
+                                      fixedSchedule,
+                                      0.03,
+                                      Actual360(),
+                                      overnightSchedule,
+                                      vars.eoniaIndex);
+
+    BOOST_CHECK_EQUAL(ois_3.fixedSchedule().tenor(), 1*Years);
+    BOOST_CHECK_EQUAL(ois_3.overnightSchedule().tenor(), 6*Months);
+    BOOST_CHECK_EQUAL(ois_3.paymentFrequency(), Semiannual);
+
+    BOOST_CHECK_EQUAL(ois_3.nominal(), nominal);
+
+    BOOST_CHECK_EQUAL(ois_3.nominals().size(), Size(1));
+    BOOST_CHECK_EQUAL(ois_3.nominals()[0], nominal);
+
+    BOOST_CHECK_EQUAL(ois_3.fixedNominals().size(), Size(1));
+    BOOST_CHECK_EQUAL(ois_3.fixedNominals()[0], nominal);
+
+    BOOST_CHECK_EQUAL(ois_3.overnightNominals().size(), Size(1));
+    BOOST_CHECK_EQUAL(ois_3.overnightNominals()[0], nominal);
+
+    // amortizing notionals, different schedules
+
+    auto ois_4 = OvernightIndexedSwap(Swap::Payer,
+                                      { nominal, nominal/2 },
+                                      fixedSchedule,
+                                      0.03,
+                                      Actual360(),
+                                      { nominal, nominal, nominal/2, nominal/2 },
+                                      overnightSchedule,
+                                      vars.eoniaIndex);
+
+    BOOST_CHECK_EQUAL(ois_4.fixedSchedule().tenor(), 1*Years);
+    BOOST_CHECK_EQUAL(ois_4.overnightSchedule().tenor(), 6*Months);
+    BOOST_CHECK_EQUAL(ois_4.paymentFrequency(), Semiannual);
+
+    BOOST_CHECK_EXCEPTION(ois_4.nominal(), Error,
+                          ExpectedErrorMessage("nominal is not constant"));
+
+    BOOST_CHECK_EXCEPTION(ois_4.nominals(), Error,
+                          ExpectedErrorMessage("different nominals"));
+
+    BOOST_CHECK_EQUAL(ois_4.fixedNominals().size(), Size(2));
+    BOOST_CHECK_EQUAL(ois_4.fixedNominals()[0], nominal);
+    BOOST_CHECK_EQUAL(ois_4.fixedNominals()[1], nominal/2);
+
+    BOOST_CHECK_EQUAL(ois_4.overnightNominals().size(), Size(4));
+    BOOST_CHECK_EQUAL(ois_4.overnightNominals()[0], nominal);
+    BOOST_CHECK_EQUAL(ois_4.overnightNominals()[1], nominal);
+    BOOST_CHECK_EQUAL(ois_4.overnightNominals()[2], nominal/2);
+    BOOST_CHECK_EQUAL(ois_4.overnightNominals()[3], nominal/2);
+}
+
+
 test_suite* OvernightIndexedSwapTest::suite() {
     auto* suite = BOOST_TEST_SUITE("Overnight-indexed swap tests");
     suite->add(QUANTLIB_TEST_CASE(&OvernightIndexedSwapTest::testFairRate));
@@ -514,11 +656,11 @@ test_suite* OvernightIndexedSwapTest::suite() {
     suite->add(QUANTLIB_TEST_CASE(&OvernightIndexedSwapTest::testCachedValue));
     suite->add(QUANTLIB_TEST_CASE(&OvernightIndexedSwapTest::testBootstrap));
     suite->add(QUANTLIB_TEST_CASE(&OvernightIndexedSwapTest::testBootstrapWithArithmeticAverage));
-    suite->add(QUANTLIB_TEST_CASE(
-        &OvernightIndexedSwapTest::testBootstrapWithTelescopicDates));
-    suite->add(QUANTLIB_TEST_CASE(
-        &OvernightIndexedSwapTest::testBootstrapWithTelescopicDatesAndArithmeticAverage));
+    suite->add(QUANTLIB_TEST_CASE(&OvernightIndexedSwapTest::testBootstrapWithTelescopicDates));
+    suite->add(QUANTLIB_TEST_CASE(&OvernightIndexedSwapTest::testBootstrapWithTelescopicDatesAndArithmeticAverage));
     suite->add(QUANTLIB_TEST_CASE(&OvernightIndexedSwapTest::testSeasonedSwaps));
     suite->add(QUANTLIB_TEST_CASE(&OvernightIndexedSwapTest::testBootstrapRegression));
+    suite->add(QUANTLIB_TEST_CASE(&OvernightIndexedSwapTest::test131BootstrapRegression));
+    suite->add(QUANTLIB_TEST_CASE(&OvernightIndexedSwapTest::testConstructorsAndNominals));
     return suite;
 }
