@@ -20,8 +20,8 @@
 /*
  Examples:
   1. Start with 12 worker processes
-     ./quantlib-test-suite --nProc=12 --log_level=message --report_level=short
-                           --build_info=yes
+    ./quantlib-test-suite --log_level=message --report_level=short
+                           --build_info=yes -- --nProc=12
   2. If parameter "--nProc" is omitted then the number
      of worker processes will be equal to the number of CPU cores.
  */
@@ -30,9 +30,9 @@
 #ifndef quantlib_parallel_test_runner_hpp
 #define quantlib_parallel_test_runner_hpp
 
+
 #include <ql/types.hpp>
 #include <ql/errors.hpp>
-#include <ql/functional.hpp>
 
 #ifdef VERSION
 /* This comes from ./configure, and for some reason it interferes with
@@ -40,8 +40,8 @@
 #undef VERSION
 #endif
 
-#include <boost/timer/timer.hpp>
-#include <boost/thread/thread.hpp>
+#include <boost/process.hpp>
+#include <boost/algorithm/string.hpp>
 #include <boost/interprocess/ipc/message_queue.hpp>
 #include <boost/interprocess/sync/scoped_lock.hpp>
 #include <boost/interprocess/sync/named_mutex.hpp>
@@ -49,42 +49,26 @@
 #define BOOST_TEST_NO_MAIN 1
 #include <boost/test/included/unit_test.hpp>
 
-#include <boost/algorithm/string.hpp>
-#include <boost/lexical_cast.hpp>
-
 #include <map>
 #include <list>
 #include <sstream>
 #include <utility>
 #include <fstream>
-
+#include <chrono>
 #include <string>
 #include <cstring>
-#include <cstdlib>
-
-#ifdef BOOST_MSVC
-#  define BOOST_LIB_NAME boost_timer
-#  include <boost/config/auto_link.hpp>
-#  undef BOOST_LIB_NAME
-#  define BOOST_LIB_NAME boost_chrono
-#  include <boost/config/auto_link.hpp>
-#  undef BOOST_LIB_NAME
-#  define BOOST_LIB_NAME boost_system
-#  include <boost/config/auto_link.hpp>
-#  undef BOOST_LIB_NAME
-#  define BOOST_LIB_NAME boost_thread
-#  include <boost/config/auto_link.hpp>
-#  undef BOOST_LIB_NAME
-#endif
+#include <thread>
+#include <limits>
 
 using boost::unit_test::test_results;
 using namespace boost::interprocess;
 using namespace boost::unit_test_framework;
+namespace bp = boost::process;
 
 
 namespace {
-    int worker(const std::string& cmd) {
-        return system(cmd.c_str());
+    int worker(const char* exe, const std::vector<std::string>& args) {
+        return bp::system(exe, bp::args=args);
     }
 
     counter_t test_enabled(test_unit_id id) {
@@ -177,13 +161,13 @@ namespace {
         out.rdbuf(s.rdbuf());
     }
 
-	std::ostream& log_stream() {
-	#if BOOST_VERSION < 106200
-		return s_log_impl().stream();
-	#else
-		return s_log_impl().m_log_formatter_data.front().stream();
-	#endif
-	}
+    std::ostream& log_stream() {
+    #if BOOST_VERSION < 106200
+        return s_log_impl().stream();
+    #else
+        return s_log_impl().m_log_formatter_data.front().stream();
+    #endif
+    }
 }
 
 
@@ -191,7 +175,7 @@ test_suite* init_unit_test_suite(int, char* []);
 
 int main( int argc, char* argv[] )
 {
-    typedef QuantLib::Time Time;
+    using QuantLib::Time;
 
     const char* const profileFileName = ".unit_test_profile.txt";
     const char* const testUnitIdQueueName = "test_unit_queue";
@@ -210,22 +194,21 @@ int main( int argc, char* argv[] )
 
             std::ifstream in(profileFileName);
             if (in.good()) {
-                for (std::string line; std::getline(in, line) != 0;) {
+                // NOLINTNEXTLINE(readability-implicit-bool-conversion)
+                for (std::string line; std::getline(in, line);) {
                     std::vector<std::string> tok;
                     boost::split(tok, line, boost::is_any_of(":"));
 
                     QL_REQUIRE(tok.size() == 2,
                         "every line should consists of two entries");
-                    runTimeLog[tok[0]] = boost::lexical_cast<Time>(tok[1]);
+                    runTimeLog[tok[0]] = std::stod(tok[1]);
                 }
             }
             in.close();
 
-            unsigned nProc = boost::thread::hardware_concurrency();
-
-            std::stringstream cmd;
-            cmd << "\"" << argv[0] << "\" ";
+            auto nProc = std::thread::hardware_concurrency();
 
+            std::vector<std::string> workerArgs;
             std::vector<char*> localArgs(1, argv[0]);
 
             for( int i = 1; i < argc; ++i ) {
@@ -234,16 +217,17 @@ int main( int argc, char* argv[] )
                 // check for number of processes
                 std::vector<std::string> tok;
                 boost::split(tok, arg, boost::is_any_of("="));
-                if (tok.size() == 2 && tok[0] == "--nProc") {
-                    nProc = boost::lexical_cast<unsigned>(tok[1]);
+                if (tok[0] == "--nProc" && tok.size() == 2) {
+                    nProc = std::stoul(tok[1]);
                 }
-                else if (arg != "--build_info=yes") {
-                    cmd << arg << " ";
+                else if (tok[0] != "--build_info") {
+                    if (tok[0] != "--run_test")
+                        workerArgs.push_back(argv[i]);
                     localArgs.push_back(argv[i]);
                 }
             }
 
-            cmd << clientModeStr;
+            workerArgs.push_back(clientModeStr);
 
             framework::init(init_unit_test_suite,
                             localArgs.size(), &localArgs[0]);
@@ -279,9 +263,9 @@ int main( int argc, char* argv[] )
                                                        std::list<test_unit_id>();
 
             // fork worker processes
-            boost::thread_group threadGroup;
-            for (unsigned i=0; i < nProc; ++i) {
-                threadGroup.create_thread(QuantLib::ext::bind(worker, cmd.str()));
+            std::vector<std::thread> threadGroup;
+            for (unsigned i = 0; i < nProc; ++i) {
+                threadGroup.emplace_back([&]() { worker(argv[0], workerArgs); });
             }
 
             struct mutex_remove {
@@ -318,8 +302,7 @@ int main( int argc, char* argv[] )
                         }
                         else {
                             testsSortedByRunTime.insert(
-                                std::make_pair(
-                                    std::numeric_limits<Time>::max(), *it));
+                                std::make_pair((std::numeric_limits<Time>::max)(), *it));
                         }
                     }
                 }
@@ -378,7 +361,9 @@ int main( int argc, char* argv[] )
             }
             out.close();
 
-            threadGroup.join_all();
+            for (auto& thread : threadGroup) {
+                thread.join();
+            }
         }
         else {
             std::stringstream logBuf;
@@ -405,13 +390,12 @@ int main( int argc, char* argv[] )
             message_queue rq(open_only, testResultQueueName);
 
             while (!id.terminate) {
-                boost::timer::cpu_timer t;
+                auto startTime = std::chrono::steady_clock::now();
 
                 #if BOOST_VERSION < 106200
                     BOOST_TEST_FOREACH( test_observer*, to,
                         framework::impl::s_frk_state().m_observers )
-                        framework::impl::s_frk_state().m_aux_em.vexecute(
-                            ext::bind( &test_observer::test_start, to, 1 ) );
+                        framework::impl::s_frk_state().m_aux_em.vexecute([&](){ to->test_start(1); });
 
                     framework::impl::s_frk_state().execute_test_tree( id.id );
 
@@ -423,8 +407,10 @@ int main( int argc, char* argv[] )
                     framework::run(id.id, false);
                 #endif
 
+                auto stopTime = std::chrono::steady_clock::now();
+                double T = std::chrono::duration_cast<std::chrono::microseconds>(stopTime - startTime).count() * 1e-6;
                 runTimeLogs.push_back(std::make_pair(
-                    framework::get(id.id, TUT_ANY).p_name, t.elapsed().wall));
+                    framework::get(id.id, TUT_ANY).p_name, T));
 
                 output_logstream(log_stream(), oldBuf, logBuf);
 
