@@ -48,9 +48,6 @@ namespace swaption_volatility_cube_test {
         ext::shared_ptr<SwapIndex> swapIndexBase, shortSwapIndexBase;
         bool vegaWeighedSmileFit;
 
-        // cleanup
-        SavedSettings backup;
-
         // utilities
         void makeAtmVolTest(const SwaptionVolatilityCube& volCube,
                             Real tolerance) {
@@ -373,7 +370,7 @@ void SwaptionVolatilityCubeTest::testObservability() {
     std::string description;
     ext::shared_ptr<SabrSwaptionVolatilityCube> volCube1_0, volCube1_1;
     // VolCube created before change of reference date
-    volCube1_0 = ext::shared_ptr<SabrSwaptionVolatilityCube>(new SabrSwaptionVolatilityCube(vars.atmVolMatrix,
+    volCube1_0 = ext::make_shared<SabrSwaptionVolatilityCube>(vars.atmVolMatrix,
                                                                 vars.cube.tenors.options,
                                                                 vars.cube.tenors.swaps,
                                                                 vars.cube.strikeSpreads,
@@ -383,7 +380,7 @@ void SwaptionVolatilityCubeTest::testObservability() {
                                                                 vars.vegaWeighedSmileFit,
                                                                 parametersGuess,
                                                                 isParameterFixed,
-                                                                true));
+                                                                true);
 
     Date referenceDate = Settings::instance().evaluationDate();
     Settings::instance().evaluationDate() =
@@ -391,7 +388,7 @@ void SwaptionVolatilityCubeTest::testObservability() {
                                           vars.conventions.optionBdc);
 
     // VolCube created after change of reference date
-    volCube1_1 = ext::shared_ptr<SabrSwaptionVolatilityCube>(new SabrSwaptionVolatilityCube(vars.atmVolMatrix,
+    volCube1_1 = ext::make_shared<SabrSwaptionVolatilityCube>(vars.atmVolMatrix,
                                                                 vars.cube.tenors.options,
                                                                 vars.cube.tenors.swaps,
                                                                 vars.cube.strikeSpreads,
@@ -401,7 +398,7 @@ void SwaptionVolatilityCubeTest::testObservability() {
                                                                 vars.vegaWeighedSmileFit,
                                                                 parametersGuess,
                                                                 isParameterFixed,
-                                                                true));
+                                                                true);
     Rate dummyStrike = 0.03;
     for (Size i=0;i<vars.cube.tenors.options.size(); i++ ) {
         for (Size j=0; j<vars.cube.tenors.swaps.size(); j++) {
@@ -605,6 +602,3 @@ test_suite* SwaptionVolatilityCubeTest::suite() {
 
     return suite;
 }
-
-
-
