@@ -77,8 +77,6 @@ void SwingOptionTest::testExtendedOrnsteinUhlenbeckProcess() {
 
     BOOST_TEST_MESSAGE("Testing extended Ornstein-Uhlenbeck process...");
 
-    SavedSettings backup;
-
     const Real speed = 2.5;
     const Volatility vol = 0.70;
     const Real level = 1.43;
@@ -135,8 +133,6 @@ void SwingOptionTest::testFdmExponentialJump1dMesher() {
 
     using namespace swing_option_test;
 
-    SavedSettings backup;
-
     Array x(2, 1.0);
     const Real beta = 100.0;
     const Real eta  = 1.0/0.4;
@@ -186,8 +182,6 @@ void SwingOptionTest::testExtOUJumpVanillaEngine() {
 
     using namespace swing_option_test;
 
-    SavedSettings backup;
-
     ext::shared_ptr<ExtOUWithJumpsProcess> jumpProcess = createKlugeProcess();
 
     const Date today = Date::todaysDate();
@@ -247,8 +241,6 @@ void SwingOptionTest::testFdBSSwingOption() {
 
     BOOST_TEST_MESSAGE("Testing Black-Scholes vanilla swing option pricing...");
 
-    SavedSettings backup;
-
     Date settlementDate = Date::todaysDate();
     Settings::instance().evaluationDate() = settlementDate;
     DayCounter dayCounter = ActualActual(ActualActual::ISDA);
@@ -328,8 +320,6 @@ void SwingOptionTest::testExtOUJumpSwingOption() {
 
     using namespace swing_option_test;
 
-    SavedSettings backup;
-
     Date settlementDate = Date::todaysDate();
     Settings::instance().evaluationDate() = settlementDate;
     DayCounter dayCounter = ActualActual(ActualActual::ISDA);
@@ -485,8 +475,6 @@ void SwingOptionTest::testKlugeChFVanillaPricing() {
 
     using namespace swing_option_test;
 
-    SavedSettings backup;
-
     Date settlementDate = Date(22, November, 2019);
     Settings::instance().evaluationDate() = settlementDate;
     DayCounter dayCounter = Actual365Fixed();
@@ -524,7 +512,7 @@ void SwingOptionTest::testKlugeChFVanillaPricing() {
         - sig*sig/(4*alpha)*(1-std::exp(-2*alpha*t))
         - lambda/beta*std::log((eta-std::exp(-beta*t))/(eta-1.0));
 
-    shape->push_back(Shape::value_type(t, ps));
+    shape->emplace_back(t, ps);
 
     const Real expected =
         RichardsonExtrapolation(
