@@ -53,9 +53,6 @@ namespace term_structures_test {
         ext::shared_ptr<YieldTermStructure> termStructure;
         ext::shared_ptr<YieldTermStructure> dummyTermStructure;
 
-        // cleanup
-        SavedSettings backup;
-
         // setup
         CommonVars() {
             calendar = TARGET();
@@ -103,7 +100,7 @@ namespace term_structures_test {
                     SwapRateHelper(swapData[i].rate/100,
                                    swapData[i].n*swapData[i].units,
                                    calendar,
-                                   Annual, Unadjusted, Thirty360(),
+                                   Annual, Unadjusted, Thirty360(Thirty360::BondBasis),
                                    index));
             }
             termStructure = ext::shared_ptr<YieldTermStructure>(new
@@ -359,7 +356,6 @@ void TermStructureTest::testCompositeZeroYieldStructures() {
 
     using namespace term_structures_test;
 
-    SavedSettings backup;
     Settings::instance().evaluationDate() = Date(10, Nov, 2017);
 
     // First curve
@@ -420,6 +416,26 @@ void TermStructureTest::testCompositeZeroYieldStructures() {
     }
 }
 
+
+void TermStructureTest::testNullTimeToReference() {
+    BOOST_TEST_MESSAGE("Testing zero-rate calculation for null time-to-reference...");
+
+    Rate rate = 0.02;
+    auto dayCount = Thirty360(Thirty360::BondBasis);
+    auto curve = FlatForward(Date(30, August, 2023), rate, dayCount);
+
+    // the time between August 30th and 31st is null for the 30/360 day count convention
+    Rate expected = rate;
+    Rate calculated = curve.zeroRate(Date(31, August, 2023), dayCount, Continuous);
+    Real tolerance = 1.0e-10;
+
+    if (std::fabs(calculated - expected) > tolerance)
+        BOOST_ERROR("unable to reproduce zero yield rate from curve\n"
+                    << std::fixed << std::setprecision(10)
+                    << "    calculated: " << calculated << "\n"
+                    << "    expected:   " << expected);
+}
+
 test_suite* TermStructureTest::suite() {
     auto* suite = BOOST_TEST_SUITE("Term structure tests");
     suite->add(QUANTLIB_TEST_CASE(&TermStructureTest::testReferenceChange));
@@ -429,12 +445,10 @@ test_suite* TermStructureTest::suite() {
     suite->add(QUANTLIB_TEST_CASE(&TermStructureTest::testFSpreadedObs));
     suite->add(QUANTLIB_TEST_CASE(&TermStructureTest::testZSpreaded));
     suite->add(QUANTLIB_TEST_CASE(&TermStructureTest::testZSpreadedObs));
-    suite->add(QUANTLIB_TEST_CASE(
-                         &TermStructureTest::testCreateWithNullUnderlying));
-    suite->add(QUANTLIB_TEST_CASE(
-                             &TermStructureTest::testLinkToNullUnderlying));
-    suite->add(QUANTLIB_TEST_CASE(
-                    &TermStructureTest::testCompositeZeroYieldStructures));
+    suite->add(QUANTLIB_TEST_CASE(&TermStructureTest::testCreateWithNullUnderlying));
+    suite->add(QUANTLIB_TEST_CASE(&TermStructureTest::testLinkToNullUnderlying));
+    suite->add(QUANTLIB_TEST_CASE(&TermStructureTest::testCompositeZeroYieldStructures));
+    suite->add(QUANTLIB_TEST_CASE(&TermStructureTest::testNullTimeToReference));
     return suite;
 }
 
